import{p as o,a as r,b as a,q as n,f as i,g as p,_ as c,h as _,j as h,T as u,P as d,C as l,M as m,s as g,i as t,k as v,l as w,m as f}from"./registerWidgets.4cc86716.js";const k={};function y(e,W){const s=r("router-view");return a(),n(s,{style:{"min-height":"100vh","box-sizing":"border-box",width:"100%"}})}const b=o(k,[["render",y]]),x=i({history:p("/"),routes:[{path:"/:path(.*)*",name:"player",component:()=>c(()=>import("./Player.fe85b3f5.js"),["assets/Player.fe85b3f5.js","assets/index.a6f97cb6.js","assets/registerWidgets.4cc86716.js","assets/registerWidgets.a7e6ab4f.css","assets/log.30671484.js","assets/broker.03e14785.js","assets/passwordlessManager.d432fb48.js","assets/icons.d4e872e2.js","assets/ActionButton.vue_vue_type_script_setup_true_lang.a22e4194.js","assets/Passwordless.42b443a5.js","assets/CircularLoading.249aa989.js","assets/CircularLoading.f81b57b4.css","assets/Passwordless.2b58e538.css","assets/executeJs.725cb8c2.js","assets/PlayerNavbar.62e8a14d.js","assets/PlayerNavbar.1542e7ca.css","assets/WidgetsFrame.8a984b59.js","assets/colors.267ec6f7.js","assets/WidgetsFrame.701a818b.css","assets/Modal.7d907bdb.js","assets/Modal.5aaf8eba.css","assets/executeJs.b0d1ede9.css","assets/broker.f87ad36d.css","assets/DashPlayer.1c42d4ac.js","assets/runnerData.1a82fcbf.js","assets/DashPlayer.a2bc20b8.css","assets/asyncComputed.f9d446a7.js","assets/Player.32200e3c.css"])}],scrollBehavior(e){if(e.hash)return{el:e.hash}}}),A=()=>{window.__dashBrokerHost="ws://localhost:8001";const e=_({render:()=>h(b)});u.init(),e.use(x),e.use(d),e.mount("#app"),e.component("VSelect",l),e.component("Markdown",m),e.component("Message",g),t(e,v),t(e,w),t(e,f)};A();
//# sourceMappingURL=player.9846710d.js.map
