import{u as a}from"./icons.b931f659.js";import{d as u,J as d,H as i,a as p,b as _,c as l,e as b,z as f,S as m,q as y}from"./registerWidgets.29e41a54.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="7f42cbc6-103b-43e3-9a87-84c46b7f6beb",e._sentryDebugIdIdentifier="sentry-dbid-7f42cbc6-103b-43e3-9a87-84c46b7f6beb")}catch{}})();const v=u({__name:"PreviewButton",props:{model:null},setup(e){const t=e,o=d(),s=i(),c=()=>{const n=o.query;s.push({path:`/_editor/${t.model.routeName}/${encodeURIComponent(t.model.path)}/preview`,query:n})};return(n,w)=>{const r=p("icon");return _(),l("button",{class:"preview-button",onClick:c},[b(r,{class:"icon",path:f(a),width:"20",height:"20",fill:"#5A677A"},null,8,["path"]),m(" Preview ")])}}});const I=y(v,[["__scopeId","data-v-4b4c109d"]]);export{I as P};
//# sourceMappingURL=PreviewButton.347f2451.js.map
