import{S as d}from"./Sidebar.f64ae14e.js";import{N as m}from"./Navbar.a0b72b66.js";import{F as l,G as p,H as u}from"./icons.79ac4c38.js";import{d as b,K as _,b as f,c as g,e as t,z as r,x as v,F as y,J as z,a as w,q as I}from"./registerWidgets.dc0b6768.js";import{a as h}from"./asyncComputed.1ef6bcd7.js";import"./gateway.320dd104.js";import{O}from"./organization.79951791.js";import"./Tooltip.e77ffe83.js";import"./logo.084e5d7c.js";import"./passwordlessManager.914ef4f9.js";import"./activeRecord.81c73286.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="a5c24d75-ba66-44de-9fbb-3fe17b4aa09a",e._sentryDebugIdIdentifier="sentry-dbid-a5c24d75-ba66-44de-9fbb-3fe17b4aa09a")}catch{}})();const x={class:"organization"},k=b({__name:"Organization",setup(e){const n=z().params.organizationId,{result:o}=h(()=>O.get(n)),s=_(()=>o.value?[{label:o.value.name,path:`/organizations/${o.value.id}`}]:void 0),i=[{name:"Organization",items:[{name:"Projects",icon:l,path:"projects"},{name:"Members",icon:p,path:"members"},{name:"Billing",icon:u,path:"billing",unavailable:!0}]}];return(B,D)=>{const c=w("router-view");return f(),g(y,null,[t(m,{breadcrumb:r(s)},null,8,["breadcrumb"]),v("div",x,[t(d,{class:"sidebar",sections:r(i)},null,8,["sections"]),t(c)])],64)}}});const J=I(k,[["__scopeId","data-v-7eef90b7"]]);export{J as default};
//# sourceMappingURL=Organization.c6930d88.js.map
