import{q as t,b as s,c}from"./registerWidgets.eddc32f4.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="c94b9170-2fe5-4fa3-9ede-d57b15cc8d5c",e._sentryDebugIdIdentifier="sentry-dbid-c94b9170-2fe5-4fa3-9ede-d57b15cc8d5c")}catch{}})();const d={},o={class:"organization-settings"};function r(e,n){return s(),c("div",o,"Organization settings")}const f=t(d,[["render",r]]);export{f as default};
//# sourceMappingURL=OrganizationSettings.75437f56.js.map
