import{D as x,_ as g}from"./DropdownMenu.45ad2be4.js";import{L as b}from"./CircularLoading.8dab92fc.js";import{d as w,b as t,t as c,c as a,x as s,N as o,B,F as r,L as d,D as C,a as L,G as _,w as S,S as T,O as I,Q as D,q as N}from"./registerWidgets.bb4c7eff.js";const y=e=>(I("data-v-a0aa59f6"),e=e(),D(),e),R={key:1,class:"runtimes-container"},U={class:"header"},V={class:"title-wrapper"},F={class:"description"},j={key:0,class:"empty-list"},q=y(()=>s("img",{src:g},null,-1)),z={class:"empty-list-title"},A={class:"empty-list-description"},E={key:1},G={key:2},M={key:2,class:"video-section"},O=y(()=>s("h1",null,"See it in action",-1)),Q=["src"],$=w({__name:"RuntimeList",props:{loading:{type:Boolean},title:null,description:null,createButtonText:null,emptyTitle:null,videoUrl:null,table:null},emits:["create"],setup(e,{emit:h}){async function u(){h("create")}return(k,H)=>{const v=L("router-link");return e.loading?(t(),c(b,{key:0,class:"loading-wrapper",justify:"center"})):(t(),a("div",R,[s("div",U,[s("div",V,[s("h1",null,o(e.title),1),s("p",F,o(e.description),1),s("button",{onClick:u},o(e.createButtonText),1)])]),e.table.rows.length===0?(t(),a("div",j,[q,s("div",z,o(e.emptyTitle),1),s("div",A,[B(k.$slots,"empty-description",{},void 0,!0)]),s("button",{onClick:u},o(e.createButtonText),1)])):(t(),a("table",E,[s("thead",null,[(t(!0),a(r,null,d(e.table.columns,(i,l)=>(t(),a("td",{key:l,class:"cell"},o(i.name),1))),128))]),(t(!0),a(r,null,d(e.table.rows,(i,l)=>{var m;return t(),a("tr",{key:l,class:_((m=i.classes)!=null?m:[])},[(t(!0),a(r,null,d(i.cells,(n,f)=>{var p;return t(),a("td",{key:f,class:_((p=n.classes)!=null?p:[])},[n.actions?(t(),c(x,{key:0,title:"Actions","highlight-last":!0,options:n.actions,payload:{key:i.key}},null,8,["options","payload"])):n.link?(t(),c(v,{key:1,to:n.link,class:"runtime-title"},{default:S(()=>[T(o(n.text),1)]),_:2},1032,["to"])):(t(),a("div",G,o(n.text),1))],2)}),128))],2)}),128))])),e.videoUrl?(t(),a("section",M,[O,s("iframe",{class:"runtimes-example-video",src:e.videoUrl,title:"runtimes example",frameborder:"0",allow:"accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture; web-share",allowfullscreen:""},null,8,Q)])):C("",!0)]))}}});const W=N($,[["__scopeId","data-v-a0aa59f6"]]);export{W as R};
//# sourceMappingURL=RuntimeList.d9b613c2.js.map
