import{P as a}from"./Passwordless.68a5dd9f.js";import{N as r}from"./Navbar.fdd7a903.js";import{d as i,b as c,c as d,e as t,H as _,q as p}from"./registerWidgets.cbdb5b20.js";import{M as m}from"./member.cafd6100.js";import"./CircularLoading.afc6a364.js";import"./lottie.3c633a53.js";import"./icons.0be4624f.js";import"./passwordlessManager.e35aa24f.js";import"./logo.084e5d7c.js";import"./asyncComputed.0300d9e5.js";import"./gateway.7f691d9f.js";import"./activeRecord.aaef4d59.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="13aa6340-e91a-4039-99ef-a3176c306692",e._sentryDebugIdIdentifier="sentry-dbid-13aa6340-e91a-4039-99ef-a3176c306692")}catch{}})();const f={class:"login"},l=i({__name:"Login",setup(e){const o=_();async function s(n){await m.login(),o.push({name:"home"})}return(n,u)=>(c(),d("div",f,[t(r,{class:"nav"}),t(a,{class:"passwordless",onDone:s})]))}});const N=p(l,[["__scopeId","data-v-c9b2b4e6"]]);export{N as default};
//# sourceMappingURL=Login.135d3f16.js.map
