import{P as r}from"./Passwordless.1bb495c6.js";import{N as a}from"./Navbar.89e03dd5.js";import{d as i,b as d,c,e as t,H as _,q as p}from"./registerWidgets.7cf0d33e.js";import{M as m}from"./member.3c3b3aba.js";import"./CircularLoading.252e5f3b.js";import"./lottie.adcbdb1d.js";import"./icons.5faf907f.js";import"./passwordlessManager.319d982e.js";import"./logo.084e5d7c.js";import"./asyncComputed.0ce7cae2.js";import"./gateway.1543d32e.js";import"./activeRecord.bddbe06b.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="9c9abb90-789a-4554-82b7-08835f43959d",e._sentryDebugIdIdentifier="sentry-dbid-9c9abb90-789a-4554-82b7-08835f43959d")}catch{}})();const f={class:"login"},b=i({__name:"Login",setup(e){const o=_();async function s(n){await m.login(),o.push({name:"home"})}return(n,l)=>(d(),c("div",f,[t(a,{class:"nav"}),t(r,{class:"passwordless",onDone:s})]))}});const N=p(b,[["__scopeId","data-v-c9b2b4e6"]]);export{N as default};
//# sourceMappingURL=Login.a6cdb5b4.js.map
