import{q as r,a,b as i,t as d,f as c,g as p,_,h as u,k as f,T as l,P as h,C as g,M as y,s as m,i as b,j as s,l as w,m as v,n as k}from"./registerWidgets.29ceb1a3.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="dfdf8562-35a3-4aec-b293-3447ed0e2434",e._sentryDebugIdIdentifier="sentry-dbid-dfdf8562-35a3-4aec-b293-3447ed0e2434")}catch{}})();const I={};function x(e,t){const o=a("router-view");return i(),d(o,{style:{"min-height":"100vh","box-sizing":"border-box",width:"100%"}})}const A=r(I,[["render",x]]),n=c({history:p("/"),routes:[{path:"/:path(.*)*",name:"player",component:()=>_(()=>import("./Player.c994ffba.js"),["assets/Player.c994ffba.js","assets/index.2f0d1fcf.js","assets/registerWidgets.29ceb1a3.js","assets/registerWidgets.a7e6ab4f.css","assets/log.59215350.js","assets/broker.bffb79f6.js","assets/passwordlessManager.68f14bfc.js","assets/icons.3ddac2d4.js","assets/ActionButton.vue_vue_type_script_setup_true_lang.58d6f594.js","assets/Passwordless.aeb71179.js","assets/CircularLoading.f0b3522c.js","assets/lottie.dc9b75c3.js","assets/CircularLoading.f81b57b4.css","assets/Passwordless.2b58e538.css","assets/executeJs.fc18b508.js","assets/PlayerNavbar.560ce26d.js","assets/PlayerNavbar.1542e7ca.css","assets/WidgetsFrame.2255c592.js","assets/colors.9ea007bd.js","assets/WidgetsFrame.701a818b.css","assets/Modal.466a15f5.js","assets/Modal.5aaf8eba.css","assets/executeJs.b0d1ede9.css","assets/broker.f87ad36d.css","assets/DashPlayer.46bd3ef2.js","assets/runnerData.b34f70e9.js","assets/DashPlayer.a2bc20b8.css","assets/asyncComputed.9ed582d0.js","assets/Player.32200e3c.css"])}],scrollBehavior(e){if(e.hash)return{el:e.hash}}}),D=()=>{window.__dashBrokerHost="ws://localhost:8001";const e=u({render:()=>f(A)});l.init(),e.use(n),e.use(h),e.mount("#app"),e.component("VSelect",g),e.component("Markdown",y),e.component("Message",m),b(e,n),s(e,w),s(e,v),s(e,k)};D();
//# sourceMappingURL=player.a5e1b535.js.map
