import{p as t,b as n,c as e}from"./registerWidgets.990552e9.js";const s={},o={class:"organization-settings"};function a(c,i){return n(),e("div",o,"Organization settings")}const _=t(s,[["render",a]]);export{_ as default};
//# sourceMappingURL=OrganizationSettings.8a73725e.js.map
