import{q as t,b as s,c as d}from"./registerWidgets.553de467.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="eb0d8bae-9a7e-4401-8395-fbedfb402db0",e._sentryDebugIdIdentifier="sentry-dbid-eb0d8bae-9a7e-4401-8395-fbedfb402db0")}catch{}})();const o={},r={class:"organization-settings"};function a(e,n){return s(),d("div",r,"Organization settings")}const c=t(o,[["render",a]]);export{c as default};
//# sourceMappingURL=OrganizationSettings.0353fc2e.js.map
