import{L}from"./CircularLoading.59d7fd3d.js";import{d as k,G as B,b as t,c as s,z as q,y as u,q as f,A as $,E as _,u as D,e as b,w as I,H as l,B as m,t as p,I as w,F as v,J as g,v as n,a as N,R,N as A,O}from"./registerWidgets.fff064a1.js";const V="/assets/empty-box.758770e4.svg",j=k({__name:"Triangle",props:{color:{type:String,required:!1}},setup(e){const i=e,o=B(()=>i.color?{borderColor:`${i.color} transparent transparent transparent`}:{});return(r,y)=>(t(),s("div",{class:"triangle",style:q(u(o))},null,4))}});const z=f(j,[["__scopeId","data-v-7ca41e33"]]),M=k({__name:"BoxShadowButton",props:{active:{type:Boolean}},setup(e){return(i,o)=>(t(),s("button",{class:_(["box-shadow-button",{active:e.active}])},[$(i.$slots,"default",{},void 0,!0)],2))}});const U=f(M,[["__scopeId","data-v-04d82775"]]),E={class:"dropdown-menu"},F={key:0},G={key:0,class:"options"},H=["onClick"],J={key:0,class:"line"},K=k({__name:"DropdownMenu",props:{title:{type:String,required:!1},options:{type:Array,required:!0},highlightLast:{type:Boolean,required:!1,default:!1},selectIcon:{type:Object,required:!1},payload:{required:!1,default:()=>({}),type:Object}},setup(e){const i=e,o=D({open:!1}),r=B(()=>i.options[i.options.length-1]),y=async h=>{await h(i.payload),o.open=!1};return(h,c)=>(t(),s("div",E,[b(U,{class:"title",active:o.open,onClick:c[0]||(c[0]=a=>o.open=!o.open)},{default:I(()=>[e.title?(t(),s("span",F,l(e.title),1)):m("",!0),e.selectIcon?(t(),p(w,{key:1,class:"select-icon",width:"18",height:"18",path:e.selectIcon,fill:"#6D7C93"},null,8,["path"])):(t(),p(z,{key:2,class:"icon",color:"#414a58"}))]),_:1},8,["active"]),o.open?(t(),s("div",G,[(t(!0),s(v,null,g(e.options.slice(0,-1),a=>(t(),s("div",{key:a.label,class:_(["option",{dangerous:!!a.dangerous}]),onClick:x=>y(a.onClick)},[b(w,{class:"option-icon",width:"14",height:"14",path:a.icon,fill:"#6D7C93"},null,8,["path"]),n("span",null,l(a.label),1)],10,H))),128)),e.highlightLast?(t(),s("div",J)):m("",!0),n("div",{class:_(["option",{dangerous:!!u(r).dangerous}]),onClick:c[1]||(c[1]=a=>y(u(r).onClick))},[b(w,{class:"option-icon",width:"14",height:"14",path:u(r).icon,fill:"#6D7C93"},null,8,["path"]),n("span",null,l(u(r).label),1)],2)])):m("",!0)]))}});const P=f(K,[["__scopeId","data-v-c4232f59"]]),S=e=>(A("data-v-3348d226"),e=e(),O(),e),Q={key:1,class:"runtimes-container"},W={class:"header"},X={class:"title-wrapper"},Y={class:"description"},Z={key:0,class:"empty-list"},ee=S(()=>n("img",{src:V},null,-1)),te={class:"empty-list-title"},se={class:"empty-list-description"},ne={key:1},oe={key:2},ae={key:2,class:"video-section"},le=S(()=>n("h1",null,"See it in action",-1)),ie=["src"],ce=k({__name:"RuntimeList",props:{loading:{type:Boolean},title:null,description:null,createButtonText:null,emptyTitle:null,videoUrl:null,table:null},emits:["create"],setup(e,{emit:i}){async function o(){i("create")}return(r,y)=>{const h=N("router-link");return e.loading?(t(),p(L,{key:0,class:"loading-wrapper",justify:"center"})):(t(),s("div",Q,[n("div",W,[n("div",X,[n("h1",null,l(e.title),1),n("p",Y,l(e.description),1),n("button",{onClick:o},l(e.createButtonText),1)])]),e.table.rows.length===0?(t(),s("div",Z,[ee,n("div",te,l(e.emptyTitle),1),n("div",se,[$(r.$slots,"empty-description",{},void 0,!0)]),n("button",{onClick:o},l(e.createButtonText),1)])):(t(),s("table",ne,[n("th",null,[(t(!0),s(v,null,g(e.table.columns,(c,a)=>(t(),s("td",{key:a,class:"cell"},l(c.name),1))),128))]),(t(!0),s(v,null,g(e.table.rows,(c,a)=>{var x;return t(),s("tr",{key:a,class:_((x=c.classes)!=null?x:[])},[(t(!0),s(v,null,g(c.cells,(d,T)=>{var C;return t(),s("td",{key:T,class:_((C=d.classes)!=null?C:[])},[d.actions?(t(),p(P,{key:0,title:"Actions","highlight-last":!0,options:d.actions,payload:{key:c.key}},null,8,["options","payload"])):d.link?(t(),p(h,{key:1,to:d.link,class:"runtime-title"},{default:I(()=>[R(l(d.text),1)]),_:2},1032,["to"])):(t(),s("div",oe,l(d.text),1))],2)}),128))],2)}),128))])),e.videoUrl?(t(),s("section",ae,[le,n("iframe",{class:"runtimes-example-video",src:e.videoUrl,title:"runtimes example",frameborder:"0",allow:"accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture; web-share",allowfullscreen:""},null,8,ie)])):m("",!0)]))}}});const ue=f(ce,[["__scopeId","data-v-3348d226"]]);export{ue as R};
//# sourceMappingURL=RuntimeList.106b52b7.js.map
