import{P as a}from"./Passwordless.dd440ef2.js";import{N as r}from"./Navbar.a3a83fd3.js";import{d as n,b as c,c as _,e as o,H as i,q as p}from"./registerWidgets.bb4c7eff.js";import{M as m}from"./member.f9d3150c.js";import"./CircularLoading.8dab92fc.js";import"./icons.e3de8035.js";import"./passwordlessManager.a806df6a.js";import"./logo.084e5d7c.js";import"./asyncComputed.0adffaf6.js";import"./gateway.99ed1590.js";import"./activeRecord.57c6bf02.js";const d={class:"login"},l=n({__name:"Login",setup(u){const e=i();async function s(t){await m.login(),e.push({name:"home"})}return(t,f)=>(c(),_("div",d,[o(r,{class:"nav"}),o(a,{class:"passwordless",onDone:s})]))}});const B=p(l,[["__scopeId","data-v-c9b2b4e6"]]);export{B as default};
//# sourceMappingURL=Login.5f706af7.js.map
