import{q as r,a,b as i,t as c,f as d,g as p,_,h as u,k as f,T as b,P as l,C as h,M as g,s as y,i as m,j as s,l as w,m as v,n as k}from"./registerWidgets.29e41a54.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="ce9fac3b-547c-43fb-bb55-fc0b440fd295",e._sentryDebugIdIdentifier="sentry-dbid-ce9fac3b-547c-43fb-bb55-fc0b440fd295")}catch{}})();const I={};function x(e,t){const o=a("router-view");return i(),c(o,{style:{"min-height":"100vh","box-sizing":"border-box",width:"100%"}})}const A=r(I,[["render",x]]),n=d({history:p("/"),routes:[{path:"/:path(.*)*",name:"player",component:()=>_(()=>import("./Player.ad2ba69d.js"),["assets/Player.ad2ba69d.js","assets/index.27b8c9c1.js","assets/registerWidgets.29e41a54.js","assets/registerWidgets.a7e6ab4f.css","assets/log.3f963c6d.js","assets/broker.1aa2622a.js","assets/passwordlessManager.88f105f1.js","assets/icons.b931f659.js","assets/ActionButton.vue_vue_type_script_setup_true_lang.c98c9ec2.js","assets/Passwordless.6b642399.js","assets/CircularLoading.0d1cd4f5.js","assets/CircularLoading.f81b57b4.css","assets/Passwordless.2b58e538.css","assets/executeJs.7cf3dd48.js","assets/PlayerNavbar.23812b1d.js","assets/PlayerNavbar.1542e7ca.css","assets/WidgetsFrame.a0cdacc5.js","assets/colors.a128ac65.js","assets/WidgetsFrame.701a818b.css","assets/Modal.7746640d.js","assets/Modal.5aaf8eba.css","assets/executeJs.b0d1ede9.css","assets/broker.f87ad36d.css","assets/DashPlayer.131f1ea2.js","assets/runnerData.38f94fff.js","assets/DashPlayer.a2bc20b8.css","assets/asyncComputed.0126d7e4.js","assets/Player.32200e3c.css"])}],scrollBehavior(e){if(e.hash)return{el:e.hash}}}),D=()=>{window.__dashBrokerHost="ws://localhost:8001";const e=u({render:()=>f(A)});b.init(),e.use(n),e.use(l),e.mount("#app"),e.component("VSelect",h),e.component("Markdown",g),e.component("Message",y),m(e,n),s(e,w),s(e,v),s(e,k)};D();
//# sourceMappingURL=player.1bd29f14.js.map
