import{q as t,b as s,c as o}from"./registerWidgets.5bbfbb1a.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="16eeeb40-1410-4241-933c-eb20ed7be71c",e._sentryDebugIdIdentifier="sentry-dbid-16eeeb40-1410-4241-933c-eb20ed7be71c")}catch{}})();const r={},c={class:"organization-settings"};function i(e,n){return s(),o("div",c,"Organization settings")}const f=t(r,[["render",i]]);export{f as default};
//# sourceMappingURL=OrganizationSettings.15bf79d4.js.map
