import{d as u,K as m,b as f,t as _,w as y,z as d,J as b,O as g,Q as h,x as i,S as n,q as w}from"./registerWidgets.29ceb1a3.js";import{a as I}from"./asyncComputed.9ed582d0.js";import"./gateway.59946eef.js";import{B as x}from"./build.9e0dc080.js";import{C as v}from"./CrudView.0e202885.js";import"./passwordlessManager.68f14bfc.js";import"./activeRecord.ab1afca6.js";import"./DropdownMenu.e7128f2e.js";import"./Modal.466a15f5.js";import"./LoadingIndicator.4fe2121c.js";import"./lottie.dc9b75c3.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="6c2eff44-7248-400d-a035-4cdff976e66a",e._sentryDebugIdIdentifier="sentry-dbid-6c2eff44-7248-400d-a035-4cdff976e66a")}catch{}})();const B=e=>(g("data-v-1b7a68a8"),e=e(),h(),e),C=B(()=>i("div",{class:"instructions"},[n(" Get started with the local editor in seconds: "),i("pre",null,`    $ pip install abstra --upgrade
    $ abstra serve ./your-project-directory
    `),n(" And you're done! Explore the local editor and start building apps. ")],-1)),S=u({__name:"Builds",setup(e){const r=b().params.projectId,{loading:c,result:p}=I(()=>x.list(r)),l=m(()=>{var o,s;return{columns:[{name:"Id"},{name:"Creation date"},{name:"Status"}],rows:(s=(o=p.value)==null?void 0:o.map(t=>({key:t.id,cells:[{text:t.id,classes:["title","centered"]},{text:t.createdAt.toLocaleString(),classes:[]},{text:t.status,classes:["centered"]}]})))!=null?s:[]}});return(o,s)=>(f(),_(v,{"entity-name":"build",loading:d(c),title:"Builds",description:"Each build is a version of your app. You can create a new build by deploying your app from the local editor.","empty-title":"No builds here yet",table:d(l)},{"empty-description":y(()=>[C]),_:1},8,["loading","table"]))}});const J=w(S,[["__scopeId","data-v-1b7a68a8"]]);export{J as default};
//# sourceMappingURL=Builds.9c226e9e.js.map
