import{P as a}from"./Passwordless.ada2efe6.js";import{N as r}from"./Navbar.be22e75c.js";import{d as n,b as _,c,e as o,H as i,q as p}from"./registerWidgets.ba12cd54.js";import{M as m}from"./member.1ae51d0f.js";import"./CircularLoading.79e96d11.js";import"./icons.ea1ef9e9.js";import"./passwordlessManager.a5941d42.js";import"./logo.084e5d7c.js";import"./utils.a13b462f.js";import"./pubsub.a0411919.js";const d={class:"login"},l=n({__name:"Login",setup(u){const e=i();async function s(t){await m.login(),e.push({name:"home"})}return(t,f)=>(_(),c("div",d,[o(r,{class:"nav"}),o(a,{class:"passwordless",onDone:s})]))}});const k=p(l,[["__scopeId","data-v-21777ab7"]]);export{k as default};
//# sourceMappingURL=Login.2b1ed2c5.js.map
