import{_ as g}from"./ActionButton.vue_vue_type_script_setup_true_lang.a22e4194.js";import{W as y,S as v}from"./WidgetsFrame.8a984b59.js";import{d as h,b as s,q as r,w,H as W,B as i,v as c,c as a,K as b,a5 as k,F as B,e as S,al as q,k as x,l as C,p as P}from"./registerWidgets.4cc86716.js";import"./colors.267ec6f7.js";const F={class:"form"},N={class:"form-wrapper"},V={key:0,class:"buttons"},A=h({__name:"WidgetPreview",setup(I){const n=W();function l(e){return x[e]||C[e]||null}function u(e){try{const t=JSON.parse(e);return t.component=l(t.type),t.response=new q,t.component?t:null}catch{return null}}function p(){const e=n.query.widget;return Array.isArray(e)?e.map(u).filter(Boolean):[u(e)]}function d(){return n.query.steps==="true"}function m(){return n.query.buttons==="true"}const f=e=>({name:e,isDefault:!1,isFocused:!1,focusOnButton:()=>{},addKeydownListener:()=>{},setElement:()=>{}});return(e,t)=>(s(),r(y,{"main-color":"#d14056",class:"preview",theme:"#fbfbfb",runtime:"dash","font-family":"Inter"},{default:w(()=>[d()?(s(),r(v,{key:0,"steps-info":{current:2,total:3}})):i("",!0),c("div",F,[c("div",N,[(s(!0),a(B,null,b(p(),(o,_)=>(s(),a("div",{key:_,class:"widget"},[(s(),r(k(o.component),{data:o.props,response:o.response},null,8,["data","response"]))]))),128))]),m()?(s(),a("div",V,[S(g,{action:f("Send")},null,8,["action"])])):i("",!0)])]),_:1}))}});const O=P(A,[["__scopeId","data-v-b5f65921"]]);export{O as default};
//# sourceMappingURL=WidgetPreview.d581bb12.js.map
