import{x as s}from"./icons.1c1f9d53.js";import{d as c,a as r,b as d,c as i,e as _,z as l,S as u,q as f}from"./registerWidgets.ad696c68.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="cc1d5754-536b-4f17-a4c9-ba1ae15d951b",e._sentryDebugIdIdentifier="sentry-dbid-cc1d5754-536b-4f17-a4c9-ba1ae15d951b")}catch{}})();const b=c({__name:"BackButton",emits:["exitFullscreenPreview"],setup(e,{emit:t}){return(o,n)=>{const a=r("icon");return d(),i("button",{class:"back-btn",onClick:n[0]||(n[0]=p=>t("exitFullscreenPreview"))},[_(a,{class:"icon",path:l(s),width:"20",height:"20",fill:"#5A677A"},null,8,["path"]),u(" Editor ")])}}});const w=f(b,[["__scopeId","data-v-eaeb3a6e"]]);export{w as B};
//# sourceMappingURL=BackButton.9130c98a.js.map
