.login[data-v-21777ab7]{display:grid;height:100%;grid-template-rows:auto 1fr;justify-items:center}.login .passwordless[data-v-21777ab7]{width:640px;max-width:calc(100vw - 40px);align-self:center}.login .passwordless[data-v-21777ab7] .next-button{background-color:#000;color:#fff;border:none;border-radius:4px;padding:.5rem 1rem;font-size:1rem;font-weight:500;cursor:pointer;transition:all .2s ease-in-out}.login .passwordless[data-v-21777ab7] .next-button:hover{background:#cccccc}.login .passwordless[data-v-21777ab7] .secondary-button{background-color:#000;color:#fff;border:none;border-radius:4px;padding:.5rem 1rem;font-size:1rem;font-weight:500;height:60px;cursor:pointer;transition:all .2s ease-in-out}.login .passwordless[data-v-21777ab7] .secondary-button:hover{background:var(--primary-color-dark)}
