import{d as u,K as m,b as _,t as b,w as f,z as d,J as y,O as g,Q as h,x as i,S as n,q as w}from"./registerWidgets.966858c5.js";import{a as I}from"./asyncComputed.af01c07f.js";import"./gateway.e0302561.js";import{B as x}from"./build.faa98d9b.js";import{C as v}from"./CrudView.081d6223.js";import"./passwordlessManager.7ff47fc0.js";import"./activeRecord.250eaea9.js";import"./DropdownMenu.668bc910.js";import"./Modal.cbda4e16.js";import"./LoadingIndicator.753c6681.js";import"./lottie.91935b30.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="26af9a25-65eb-400e-b785-6cb7461c7fa1",e._sentryDebugIdIdentifier="sentry-dbid-26af9a25-65eb-400e-b785-6cb7461c7fa1")}catch{}})();const B=e=>(g("data-v-1b7a68a8"),e=e(),h(),e),C=B(()=>i("div",{class:"instructions"},[n(" Get started with the local editor in seconds: "),i("pre",null,`    $ pip install abstra --upgrade
    $ abstra serve ./your-project-directory
    `),n(" And you're done! Explore the local editor and start building apps. ")],-1)),S=u({__name:"Builds",setup(e){const r=y().params.projectId,{loading:c,result:p}=I(()=>x.list(r)),l=m(()=>{var o,s;return{columns:[{name:"Id"},{name:"Creation date"},{name:"Status"}],rows:(s=(o=p.value)==null?void 0:o.map(t=>({key:t.id,cells:[{text:t.id,classes:["title","centered"]},{text:t.createdAt.toLocaleString(),classes:[]},{text:t.status,classes:["centered"]}]})))!=null?s:[]}});return(o,s)=>(_(),b(v,{"entity-name":"build",loading:d(c),title:"Builds",description:"Each build is a version of your app. You can create a new build by deploying your app from the local editor.","empty-title":"No builds here yet",table:d(l)},{"empty-description":f(()=>[C]),_:1},8,["loading","table"]))}});const J=w(S,[["__scopeId","data-v-1b7a68a8"]]);export{J as default};
//# sourceMappingURL=Builds.d73ab746.js.map
