import{r as a,K as f,R as v}from"./registerWidgets.eddc32f4.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="88b1cb49-849a-423f-915d-c850b9cdd94e",e._sentryDebugIdIdentifier="sentry-dbid-88b1cb49-849a-423f-915d-c850b9cdd94e")}catch{}})();const i=e=>{const t=a(Date.now()),l=a(!0),r=a(null),u=a(null),o=f(()=>(t.value,e())),s=n=>{r.value=n,u.value=null,l.value=!1},c=n=>{u.value=n,r.value=null,l.value=!1},d=()=>{t.value=Date.now()};return v(()=>o.value,()=>{r.value=null,l.value=!0,o.value.then(s).catch(n=>{console.error(n),c(n)})}),o.value.then(s),{result:r,loading:l,error:u,refetch:d}};export{i as a};
//# sourceMappingURL=asyncComputed.562c187e.js.map
