import{_ as y}from"./logo.084e5d7c.js";import{p as i,b as s,c as o,N as u,O as p,v as t,d as m,G as $,a as x,y as c,L as b,e as n,w as g,R as v,F as L,K as N,B,ao as C}from"./registerWidgets.4cc86716.js";import{p as l}from"./passwordlessManager.d432fb48.js";import{a as I}from"./asyncComputed.f9d446a7.js";const w={},h=e=>(u("data-v-439be421"),e=e(),p(),e),S={class:"logo"},V=h(()=>t("img",{class:"logo-img",src:y,alt:"Abstra cloud logo"},null,-1)),R=h(()=>t("span",null,"Abstra Cloud",-1)),A=[V,R];function F(e,_){return s(),o("div",S,A)}const U=i(w,[["render",F],["__scopeId","data-v-439be421"]]),D={key:0},E={key:1,class:"logged"},G={class:"author-email"},K={key:2},M=m({__name:"LoginBlock",setup(e){const _=$(),{result:r,loading:a,refetch:d}=I(async()=>l.getUser());function f(){l.removeUser(),d(),_.push({name:"login"})}return(Q,W)=>{const k=x("router-link");return c(a)?(s(),o("div",D,"loading...")):c(r)?(s(),o("div",E,[t("span",G,b(c(r).claims.email),1),t("button",{class:"btn",onClick:f},"Logout")])):(s(),o("div",K,[n(k,{class:"btn",to:"/login"},{default:g(()=>[v("Login")]),_:1})]))}}});const O=i(M,[["__scopeId","data-v-6c08207b"]]),T=e=>(u("data-v-cf48b8cc"),e=e(),p(),e),j={class:"nav"},q={class:"left"},z={key:0,class:"breadcrumb-container"},H=T(()=>t("span",{class:"divider"},">",-1)),J={class:"right"},P=m({__name:"Navbar",props:{breadcrumb:null},setup(e){return(_,r)=>(s(),o("nav",j,[t("div",q,[n(U),e.breadcrumb?(s(),o("div",z,[(s(!0),o(L,null,N(e.breadcrumb,(a,d)=>(s(),o("span",{key:d,class:"breadcrumb-item"},[n(c(C),{class:"breadcrumb-link",to:a.path},{default:g(()=>[v(b(a.label),1)]),_:2},1032,["to"]),H]))),128))])):B("",!0)]),t("div",J,[n(O)])]))}});const se=i(P,[["__scopeId","data-v-cf48b8cc"]]);export{se as N};
//# sourceMappingURL=Navbar.1dd95194.js.map
