import{P as r}from"./Passwordless.896adb7f.js";import{N as a}from"./Navbar.d5c7f166.js";import{d,b as i,c,e as t,H as _,q as p}from"./registerWidgets.ad696c68.js";import{M as b}from"./member.fbdd8002.js";import"./CircularLoading.1b0ceab6.js";import"./lottie.d1a83079.js";import"./icons.1c1f9d53.js";import"./passwordlessManager.86ad8b48.js";import"./logo.084e5d7c.js";import"./asyncComputed.40a67fe8.js";import"./gateway.d1b7c117.js";import"./activeRecord.da3a3625.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="4eec9bb5-b975-41d4-b9e4-2de8b63d3380",e._sentryDebugIdIdentifier="sentry-dbid-4eec9bb5-b975-41d4-b9e4-2de8b63d3380")}catch{}})();const m={class:"login"},l=d({__name:"Login",setup(e){const o=_();async function s(n){await b.login(),o.push({name:"home"})}return(n,f)=>(i(),c("div",m,[t(a,{class:"nav"}),t(r,{class:"passwordless",onDone:s})]))}});const N=p(l,[["__scopeId","data-v-c9b2b4e6"]]);export{N as default};
//# sourceMappingURL=Login.49576aa4.js.map
