import{d as p,K as u,b as y,t as g,z as s,J as _}from"./registerWidgets.2bf05ebf.js";import{a as w}from"./asyncComputed.62d26af7.js";import"./gateway.61c8f3b2.js";import{M as i}from"./member.de81de15.js";import{C as I}from"./CrudView.dd7d6012.js";import"./passwordlessManager.08604e70.js";import"./activeRecord.ffd94d66.js";import"./DropdownMenu.cbfec719.js";import"./Modal.5e63635f.js";import"./LoadingIndicator.0bf264ad.js";import"./lottie.314baab9.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="30c3a2bf-d3e1-43a7-b077-0d60ffa985eb",e._sentryDebugIdIdentifier="sentry-dbid-30c3a2bf-d3e1-43a7-b077-0d60ffa985eb")}catch{}})();const A=p({__name:"Members",setup(e){const o=_().params.organizationId,m=[{key:"email",label:"Email"}],l=async t=>{await i.create(o,t.email),b()},{loading:d,result:c,refetch:b}=w(()=>i.list(o)),f=u(()=>{var t,r;return{columns:[{name:"Email"},{name:"Role"}],rows:(r=(t=c.value)==null?void 0:t.map(n=>({key:n.email,cells:[{text:n.email,classes:["title","centered"]},{text:n.role,classes:["centered"]}]})))!=null?r:[]}});return(t,r)=>(y(),g(I,{"entity-name":"members",loading:s(d),title:"Organization members",description:"List all organization members.","empty-title":"No members yet",table:s(f),"create-button-text":"Add members",fields:m,onCreate:l},null,8,["loading","table"]))}});export{A as default};
//# sourceMappingURL=Members.6128e2d3.js.map
