import{P as a}from"./Passwordless.9bcddd63.js";import{N as r}from"./Navbar.94f953b7.js";import{d as c,b as i,c as d,e as t,H as _,q as p}from"./registerWidgets.c33434b6.js";import{M as m}from"./member.18ed8e83.js";import"./CircularLoading.8d9a0f4b.js";import"./lottie.02d4abc1.js";import"./icons.da9eecb0.js";import"./passwordlessManager.dde65e6d.js";import"./logo.084e5d7c.js";import"./asyncComputed.2a2efb36.js";import"./gateway.b560ee02.js";import"./activeRecord.cbf414d4.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="667cb161-3a25-412a-a55c-a9533ebe7bc7",e._sentryDebugIdIdentifier="sentry-dbid-667cb161-3a25-412a-a55c-a9533ebe7bc7")}catch{}})();const b={class:"login"},l=c({__name:"Login",setup(e){const o=_();async function s(n){await m.login(),o.push({name:"home"})}return(n,f)=>(i(),d("div",b,[t(r,{class:"nav"}),t(a,{class:"passwordless",onDone:s})]))}});const N=p(l,[["__scopeId","data-v-c9b2b4e6"]]);export{N as default};
//# sourceMappingURL=Login.5241b82b.js.map
