[data-v-8f71f9c1]:root{--main-font-family: DM Sans, sans-serif}[data-v-8f71f9c1]:root{--abstra-neutral-color: #bbb;--abstra-primary-color: #ffee56;--abstra-dark-text-color: #1b1b23;--abstra-normal-text-color: #414a58;--abstra-main-color-dark: #343b46;--abstra-main-color-light: #ffd84c;--abstra-secondary-color-dark: #4c5767;--abstra-secondary-color-light: #feab4c;--abstra-background-base: #f9fafb;--abstra-main-color-blue: #2479df}.background-theme[data-v-8f71f9c1]{background-repeat:no-repeat;background-size:cover;background-position:center}*[data-v-8f71f9c1]{padding:0;margin:0}.form-settings[data-v-8f71f9c1]{width:960px;max-width:calc(100vw - 40px);padding:50px 0;align-self:center;display:flex;flex-direction:column;gap:30px;background-color:#fff}.form-settings .content[data-v-8f71f9c1]{display:flex;flex-direction:column;gap:30px}.chevron-icon[data-v-8f71f9c1]{transition:transform .3s ease-in-out}.chevron-icon.open[data-v-8f71f9c1]{transform:rotate(180deg)}.logo-image[data-v-8f71f9c1]{width:90px}.logo-upload-button[data-v-8f71f9c1]{margin-left:10px;height:2rem}.content-row[data-v-8f71f9c1]{display:flex;flex-direction:row;align-items:center;gap:40px}.subsection[data-v-8f71f9c1]{display:flex;flex-direction:column;gap:10px;width:100%}.subsection .subsection-label[data-v-8f71f9c1]{font-style:normal;font-weight:400;font-size:12px;line-height:16px;color:#6d7c93}.property[data-v-8f71f9c1]{display:flex;width:100%;gap:8px}.property.column[data-v-8f71f9c1]{flex-direction:column}.property.column .property-label[data-v-8f71f9c1]{align-self:stretch}.property .property-label[data-v-8f71f9c1]{min-width:15%;display:flex;font-size:10px;color:#6d7c93}.logo-property[data-v-8f71f9c1]{display:flex;align-items:center;flex-direction:row;gap:20px}.logo-property .logo-input-container[data-v-8f71f9c1]{display:flex;flex-direction:column;gap:10px;flex:1}.logo-property .logo-input-container .instructions[data-v-8f71f9c1]{font-family:DM Sans;font-style:normal;font-weight:500;font-size:10px;line-height:14px;color:#8692a5}.logo-property .logo-input-container .logo-label[data-v-8f71f9c1]{color:#6d7c93;font-family:DM Sans;font-style:normal;font-weight:700;font-size:10px;line-height:14px}.logo-property .logo-input-container .logo-input[data-v-8f71f9c1]{display:flex;flex-direction:row}.property-input[data-v-8f71f9c1]{flex:1;font-size:.8em;padding:.5em 1em;border:1px solid #d4d8de;border-radius:6px;align-self:stretch;color:#8692a5}.icon[data-v-8f71f9c1]{fill:#5a677a}.path-input[data-v-8f71f9c1]{display:flex;flex-direction:row;align-items:center;gap:6px}.path-input .home-label[data-v-8f71f9c1]{font-size:10px;color:#8692a5}.error[data-v-8f71f9c1]{font-size:.8rem;font-weight:700;color:red}[data-v-ab1b9fa2]:root{--main-font-family: DM Sans, sans-serif}[data-v-ab1b9fa2]:root{--abstra-neutral-color: #bbb;--abstra-primary-color: #ffee56;--abstra-dark-text-color: #1b1b23;--abstra-normal-text-color: #414a58;--abstra-main-color-dark: #343b46;--abstra-main-color-light: #ffd84c;--abstra-secondary-color-dark: #4c5767;--abstra-secondary-color-light: #feab4c;--abstra-background-base: #f9fafb;--abstra-main-color-blue: #2479df}.page[data-v-ab1b9fa2]{height:100vh;display:flex;flex-direction:column}.preview-button[data-v-ab1b9fa2],.save-button[data-v-ab1b9fa2]{font-family:DM Sans,sans-serif;cursor:pointer;display:flex;justify-content:center;align-items:center;gap:6px;padding:7px 14px;height:30px;font-weight:500;font-size:14px;line-height:16px;margin-right:16px;color:#5a677a;border:none;background:transparent}.save-button[data-v-ab1b9fa2]{border-radius:5px;border-width:1px;border-color:#5a677a}.save-button.changes[data-v-ab1b9fa2]{border-style:solid}.save-button[data-v-ab1b9fa2]:not(.changes){color:#5a677a;border-style:none;opacity:.5}
