.logo[data-v-462c26c1]{display:flex;align-items:center}.logo .logo-img[data-v-462c26c1]{height:50px}.logo span[data-v-462c26c1]{font-size:18px;font-weight:600;margin-left:10px}.logged[data-v-ec693579]{display:flex;align-items:center;gap:10px}.btn[data-v-ec693579]{background:#272d35;border-radius:4px;color:#fff;padding:8px 16px;font-size:14px;font-weight:500;border:none;cursor:pointer}[data-v-1033a895]:root{--main-font-family: DM Sans, sans-serif}[data-v-1033a895]:root{--abstra-neutral-color: #bbb;--abstra-primary-color: #ffee56;--abstra-dark-text-color: #1b1b23;--abstra-normal-text-color: #414a58;--abstra-main-color-dark: #343b46;--abstra-main-color-light: #ffd84c;--abstra-secondary-color-dark: #4c5767;--abstra-secondary-color-light: #feab4c;--abstra-background-base: #f9fafb;--abstra-main-color-blue: #2479df}.nav[data-v-1033a895]{display:flex;align-items:center;justify-content:space-between;box-shadow:0 0 100px #00000005;box-sizing:border-box;width:100%;height:48px;padding:0 16px;gap:20px}.nav .left[data-v-1033a895]{display:flex}.nav .left .breadcrumb-container[data-v-1033a895]{display:flex;align-items:center;color:#414a58}.nav .left .breadcrumb-container .breadcrumb-item .breadcrumb-link[data-v-1033a895]{text-decoration:none;color:#272d35;font-weight:400;font-size:16px}.nav .left .breadcrumb-container .breadcrumb-item .breadcrumb-link[data-v-1033a895]:hover{cursor:pointer;text-decoration:underline}.nav .left .breadcrumb-container .breadcrumb-item:last-child .divider[data-v-1033a895]{display:none}.nav .left .breadcrumb-container .divider[data-v-1033a895]{margin:0 8px}
