import{d as y,K as b,b as h,t as g,z as d,H as _}from"./registerWidgets.eddc32f4.js";import{f as H,g as w,h as C}from"./icons.54ab2234.js";import{a as I}from"./asyncComputed.562c187e.js";import{H as u}from"./hooks.15bdfd54.js";import{R as x}from"./RuntimeList.368e500b.js";import"./activeRecord.ed4e0294.js";import"./DropdownMenu.07e05b99.js";import"./CircularLoading.c96bd1c9.js";import"./lottie.6d443700.js";(function(){try{var a=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(a._sentryDebugIds=a._sentryDebugIds||{},a._sentryDebugIds[n]="c4760ac1-0b24-4a0f-94b1-f4e71cc9b5f3",a._sentryDebugIdIdentifier="sentry-dbid-c4760ac1-0b24-4a0f-94b1-f4e71cc9b5f3")}catch{}})();const U=y({__name:"Hooks",setup(a){const n=_(),{loading:c,result:s,refetch:r}=I(()=>u.list()),l=({key:e})=>n.push({path:`/_editor/hook/${encodeURIComponent(e)}`}),p=async({key:e})=>{var o,t;await((t=(o=s.value)==null?void 0:o.find(i=>i.path===e))==null?void 0:t.duplicate()),r()},f=async()=>{const e=await u.create();l({key:e.path})},m=async({key:e})=>{var o,t;confirm("Are you sure you want to delete this hook?")&&(await((t=(o=s.value)==null?void 0:o.find(i=>i.path===e))==null?void 0:t.delete()),r())},k=b(()=>{var e,o;return{columns:[{name:"Hook Name"},{name:"Path"},{name:"Hook Actions"}],rows:(o=(e=s.value)==null?void 0:e.map(t=>({key:t.path,cells:[{text:t.title,classes:["title","centered"],link:`/_editor/hook/${encodeURIComponent(t.path)}`},{text:t.path},{text:"",classes:["centered"],actions:[{icon:H,label:"Delete",onClick:m,dangerous:!0},{icon:w,label:"Edit Hook",onClick:l},{icon:C,label:"Duplicate",onClick:p}]}]})))!=null?o:[]}});return(e,o)=>(h(),g(x,{loading:d(c),title:"Python Hooks",description:"Trigger your Python scripts with a request.","create-button-text":"Create Hook","empty-title":"No hooks here yet",table:d(k),onCreate:f},null,8,["loading","table"]))}});export{U as default};
//# sourceMappingURL=Hooks.629bf040.js.map
