import{x as a}from"./icons.0be4624f.js";import{d as c,a as r,b as i,c as d,e as _,z as l,S as f,q as b}from"./registerWidgets.cbdb5b20.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="8ba0fc90-bfe6-493b-94c0-18cb50e1e123",e._sentryDebugIdIdentifier="sentry-dbid-8ba0fc90-bfe6-493b-94c0-18cb50e1e123")}catch{}})();const u=c({__name:"BackButton",emits:["exitFullscreenPreview"],setup(e,{emit:t}){return(o,n)=>{const s=r("icon");return i(),d("button",{class:"back-btn",onClick:n[0]||(n[0]=p=>t("exitFullscreenPreview"))},[_(s,{class:"icon",path:l(a),width:"20",height:"20",fill:"#5A677A"},null,8,["path"]),f(" Editor ")])}}});const w=b(u,[["__scopeId","data-v-eaeb3a6e"]]);export{w as B};
//# sourceMappingURL=BackButton.dbc7fbc7.js.map
