import{P as r}from"./Passwordless.399a4808.js";import{N as a}from"./Navbar.df60a519.js";import{d as i,b as d,c,e as t,H as _,q as f}from"./registerWidgets.8e2e133d.js";import{M as p}from"./member.7e42d6a2.js";import"./CircularLoading.b144822c.js";import"./lottie.7a1c6d39.js";import"./icons.35c960d1.js";import"./passwordlessManager.cb9f88a0.js";import"./logo.084e5d7c.js";import"./asyncComputed.a6090ca2.js";import"./gateway.57276d9e.js";import"./activeRecord.eba5e90d.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="f651a0f3-ff20-4271-878a-9b5bb3919b13",e._sentryDebugIdIdentifier="sentry-dbid-f651a0f3-ff20-4271-878a-9b5bb3919b13")}catch{}})();const m={class:"login"},b=i({__name:"Login",setup(e){const o=_();async function s(n){await p.login(),o.push({name:"home"})}return(n,l)=>(d(),c("div",m,[t(a,{class:"nav"}),t(r,{class:"passwordless",onDone:s})]))}});const N=f(b,[["__scopeId","data-v-c9b2b4e6"]]);export{N as default};
//# sourceMappingURL=Login.dfa89028.js.map
