import{q as t,b as s,c as d}from"./registerWidgets.8e2e133d.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="82d0c481-4a50-4afe-8df5-f41b382bd903",e._sentryDebugIdIdentifier="sentry-dbid-82d0c481-4a50-4afe-8df5-f41b382bd903")}catch{}})();const o={},r={class:"organization-settings"};function a(e,n){return s(),d("div",r,"Organization settings")}const c=t(o,[["render",a]]);export{c as default};
//# sourceMappingURL=OrganizationSettings.e90c5753.js.map
