import{d as f,K as b,b as y,t as g,z as s,J as _}from"./registerWidgets.fce18b61.js";import{a as w}from"./asyncComputed.aceaab2d.js";import"./gateway.6f3c5fa6.js";import{M as i}from"./member.5915ce2c.js";import{C as I}from"./CrudView.042abd13.js";import"./passwordlessManager.2cd33479.js";import"./activeRecord.5ca93a47.js";import"./DropdownMenu.94fbd8d3.js";import"./Modal.eb38c07a.js";import"./LoadingIndicator.b25e3053.js";import"./lottie.84b3db69.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="4d2bdc97-6461-49dc-86ff-59291a07ae21",e._sentryDebugIdIdentifier="sentry-dbid-4d2bdc97-6461-49dc-86ff-59291a07ae21")}catch{}})();const A=f({__name:"Members",setup(e){const o=_().params.organizationId,m=[{key:"email",label:"Email"}],l=async t=>{await i.create(o,t.email),p()},{loading:d,result:c,refetch:p}=w(()=>i.list(o)),u=b(()=>{var t,r;return{columns:[{name:"Email"},{name:"Role"}],rows:(r=(t=c.value)==null?void 0:t.map(n=>({key:n.email,cells:[{text:n.email,classes:["title","centered"]},{text:n.role,classes:["centered"]}]})))!=null?r:[]}});return(t,r)=>(y(),g(I,{"entity-name":"members",loading:s(d),title:"Organization members",description:"List all organization members.","empty-title":"No members yet",table:s(u),"create-button-text":"Add members",fields:m,onCreate:l},null,8,["loading","table"]))}});export{A as default};
//# sourceMappingURL=Members.7484ec85.js.map
