import{d as l,K as u,b as m,t as _,w as y,z as s,J as b,O as f,Q as h,x as r,S as i,q as x}from"./registerWidgets.88d12ae1.js";import{a as B}from"./asyncComputed.0bf661db.js";import"./gateway.042591ee.js";import{B as g}from"./build.07d07ee7.js";import{C as v}from"./CrudView.9d8bebef.js";import"./passwordlessManager.a5c71e7e.js";import"./activeRecord.57c6bf02.js";import"./DropdownMenu.d2cd7589.js";import"./CircularLoading.0c459b72.js";import"./Modal.f14dcc44.js";const w=e=>(f("data-v-1b7a68a8"),e=e(),h(),e),I=w(()=>r("div",{class:"instructions"},[i(" Get started with the local editor in seconds: "),r("pre",null,`    $ pip install abstra --upgrade
    $ abstra serve ./your-project-directory
    `),i(" And you're done! Explore the local editor and start building apps. ")],-1)),C=l({__name:"Builds",setup(e){const d=b().params.projectId,{loading:c,result:n}=B(()=>g.list(d)),p=u(()=>{var a,o;return{columns:[{name:"Id"},{name:"Creation date"},{name:"Status"}],rows:(o=(a=n.value)==null?void 0:a.map(t=>({key:t.id,cells:[{text:t.id,classes:["title","centered"]},{text:t.createdAt.toLocaleString(),classes:[]},{text:t.status,classes:["centered"]}]})))!=null?o:[]}});return(a,o)=>(m(),_(v,{"entity-name":"build",loading:s(c),title:"Builds",description:"Each build is a version of your app. You can create a new build by deploying your app from the local editor.","empty-title":"No builds here yet",table:s(p)},{"empty-description":y(()=>[I]),_:1},8,["loading","table"]))}});const J=x(C,[["__scopeId","data-v-1b7a68a8"]]);export{J as default};
//# sourceMappingURL=Builds.957c9bb6.js.map
