import{x as s}from"./icons.012820f9.js";import{d as c,a as r,b as i,c as d,e as _,z as f,S as b,q as l}from"./registerWidgets.553de467.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="a5b420c6-a249-4b40-b9fc-31ffb75bac33",e._sentryDebugIdIdentifier="sentry-dbid-a5b420c6-a249-4b40-b9fc-31ffb75bac33")}catch{}})();const u=c({__name:"BackButton",emits:["exitFullscreenPreview"],setup(e,{emit:t}){return(o,n)=>{const a=r("icon");return i(),d("button",{class:"back-btn",onClick:n[0]||(n[0]=p=>t("exitFullscreenPreview"))},[_(a,{class:"icon",path:f(s),width:"20",height:"20",fill:"#5A677A"},null,8,["path"]),b(" Editor ")])}}});const w=l(u,[["__scopeId","data-v-eaeb3a6e"]]);export{w as B};
//# sourceMappingURL=BackButton.230539cd.js.map
