import{q as t,b as e,c}from"./registerWidgets.69eb7b40.js";const s={},o={class:"project-settings"};function n(r,_){return e(),c("div",o,"Project settings")}const i=t(s,[["render",n]]);export{i as default};
//# sourceMappingURL=ProjectSettings.bc8162ca.js.map
