import{q as r,a,b as i,t as c,f as d,g as p,_,h as u,k as f,T as l,P as h,C as b,M as g,s as y,i as m,j as s,l as w,m as v,n as k}from"./registerWidgets.fce18b61.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="16fd428f-8738-4133-90be-b7ee3b6fc135",e._sentryDebugIdIdentifier="sentry-dbid-16fd428f-8738-4133-90be-b7ee3b6fc135")}catch{}})();const I={};function x(e,t){const o=a("router-view");return i(),c(o,{style:{"min-height":"100vh","box-sizing":"border-box",width:"100%"}})}const A=r(I,[["render",x]]),n=d({history:p("/"),routes:[{path:"/:path(.*)*",name:"player",component:()=>_(()=>import("./Player.143a4b12.js"),["assets/Player.143a4b12.js","assets/index.130927bb.js","assets/registerWidgets.fce18b61.js","assets/registerWidgets.a7e6ab4f.css","assets/log.608a083b.js","assets/broker.41b4afbe.js","assets/passwordlessManager.2cd33479.js","assets/icons.99afd58c.js","assets/ActionButton.vue_vue_type_script_setup_true_lang.9474c75a.js","assets/Passwordless.1c4f72d4.js","assets/CircularLoading.01aaac49.js","assets/lottie.84b3db69.js","assets/CircularLoading.f81b57b4.css","assets/Passwordless.2b58e538.css","assets/executeJs.7046116d.js","assets/PlayerNavbar.079e91f3.js","assets/PlayerNavbar.1542e7ca.css","assets/WidgetsFrame.bc1c8c2c.js","assets/colors.655cb633.js","assets/WidgetsFrame.701a818b.css","assets/Modal.eb38c07a.js","assets/Modal.5aaf8eba.css","assets/executeJs.b0d1ede9.css","assets/broker.f87ad36d.css","assets/DashPlayer.efede082.js","assets/runnerData.945d2a2d.js","assets/DashPlayer.a2bc20b8.css","assets/asyncComputed.aceaab2d.js","assets/Player.32200e3c.css"])}],scrollBehavior(e){if(e.hash)return{el:e.hash}}}),D=()=>{window.__dashBrokerHost="ws://localhost:8001";const e=u({render:()=>f(A)});l.init(),e.use(n),e.use(h),e.mount("#app"),e.component("VSelect",b),e.component("Markdown",g),e.component("Message",y),m(e,n),s(e,w),s(e,v),s(e,k)};D();
//# sourceMappingURL=player.1e75ee12.js.map
