import{q as r,a,b as i,t as d,f as c,g as p,_,h as u,k as l,T as f,P as h,C as b,M as g,s as y,i as m,j as s,l as w,m as v,n as k}from"./registerWidgets.966858c5.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="02d01b02-59de-41d0-962d-742f5e57bcbd",e._sentryDebugIdIdentifier="sentry-dbid-02d01b02-59de-41d0-962d-742f5e57bcbd")}catch{}})();const I={};function x(e,t){const o=a("router-view");return i(),d(o,{style:{"min-height":"100vh","box-sizing":"border-box",width:"100%"}})}const A=r(I,[["render",x]]),n=c({history:p("/"),routes:[{path:"/:path(.*)*",name:"player",component:()=>_(()=>import("./Player.fb2a863f.js"),["assets/Player.fb2a863f.js","assets/index.13f616dd.js","assets/registerWidgets.966858c5.js","assets/registerWidgets.a7e6ab4f.css","assets/log.6e551cbe.js","assets/broker.c42055e6.js","assets/passwordlessManager.7ff47fc0.js","assets/icons.e22fc21e.js","assets/ActionButton.vue_vue_type_script_setup_true_lang.d3e0033d.js","assets/Passwordless.e2d42681.js","assets/CircularLoading.11f239a9.js","assets/lottie.91935b30.js","assets/CircularLoading.f81b57b4.css","assets/Passwordless.2b58e538.css","assets/executeJs.e04bbde9.js","assets/PlayerNavbar.05d4c38b.js","assets/PlayerNavbar.1542e7ca.css","assets/WidgetsFrame.75c515d4.js","assets/colors.c4671dfa.js","assets/WidgetsFrame.701a818b.css","assets/Modal.cbda4e16.js","assets/Modal.5aaf8eba.css","assets/executeJs.b0d1ede9.css","assets/broker.f87ad36d.css","assets/DashPlayer.5745556b.js","assets/runnerData.a6030cb4.js","assets/DashPlayer.a2bc20b8.css","assets/asyncComputed.af01c07f.js","assets/Player.32200e3c.css"])}],scrollBehavior(e){if(e.hash)return{el:e.hash}}}),D=()=>{window.__dashBrokerHost="ws://localhost:8001";const e=u({render:()=>l(A)});f.init(),e.use(n),e.use(h),e.mount("#app"),e.component("VSelect",b),e.component("Markdown",g),e.component("Message",y),m(e,n),s(e,w),s(e,v),s(e,k)};D();
//# sourceMappingURL=player.e2d81634.js.map
