.background[data-v-0ed99ca1]{position:fixed;visibility:hidden;top:0;left:0;right:0;bottom:0;background:rgba(0,0,0,.5);z-index:9999}.visible[data-v-0ed99ca1]{visibility:unset}.container[data-v-0ed99ca1]{position:absolute;top:50%;left:50%;transform:translate(-50%,-50%);width:80%;height:80%;background:#fff;border-radius:5px;box-shadow:0 4px 8px #0003}.header[data-v-0ed99ca1]{width:100%;height:10%;display:flex;justify-content:center;align-items:center;border-bottom:1px solid #ccc}.content[data-v-0ed99ca1]{width:100%;height:100%;display:flex;flex-direction:column;justify-content:center;align-items:center}
