import{x as s}from"./icons.e22fc21e.js";import{d as c,a as r,b as i,c as f,e as d,z as _,S as l,q as u}from"./registerWidgets.966858c5.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="097587f4-6bfc-4171-bccf-aa0f8e335c15",e._sentryDebugIdIdentifier="sentry-dbid-097587f4-6bfc-4171-bccf-aa0f8e335c15")}catch{}})();const p=c({__name:"BackButton",emits:["exitFullscreenPreview"],setup(e,{emit:t}){return(o,n)=>{const a=r("icon");return i(),f("button",{class:"back-btn",onClick:n[0]||(n[0]=b=>t("exitFullscreenPreview"))},[d(a,{class:"icon",path:_(s),width:"20",height:"20",fill:"#5A677A"},null,8,["path"]),l(" Editor ")])}}});const w=u(p,[["__scopeId","data-v-eaeb3a6e"]]);export{w as B};
//# sourceMappingURL=BackButton.3bc28600.js.map
