import{S as d}from"./Sidebar.73e22c10.js";import{N as m}from"./Navbar.eac3ae22.js";import{F as l,G as p,H as u}from"./icons.96376736.js";import{d as b,K as _,b as f,c as g,e as t,z as r,x as v,F as y,J as z,a as w,q as I}from"./registerWidgets.80830a62.js";import{a as h}from"./asyncComputed.7fd138fd.js";import"./gateway.0f7f822d.js";import{O}from"./organization.dfe98db9.js";import"./Tooltip.102031c9.js";import"./logo.084e5d7c.js";import"./passwordlessManager.65c1d475.js";import"./activeRecord.dd1973bd.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="238bbb36-9de0-439e-97d5-fcca373c2198",e._sentryDebugIdIdentifier="sentry-dbid-238bbb36-9de0-439e-97d5-fcca373c2198")}catch{}})();const x={class:"organization"},k=b({__name:"Organization",setup(e){const n=z().params.organizationId,{result:o}=h(()=>O.get(n)),s=_(()=>o.value?[{label:o.value.name,path:`/organizations/${o.value.id}`}]:void 0),i=[{name:"Organization",items:[{name:"Projects",icon:l,path:"projects"},{name:"Members",icon:p,path:"members"},{name:"Billing",icon:u,path:"billing",unavailable:!0}]}];return(B,D)=>{const c=w("router-view");return f(),g(y,null,[t(m,{breadcrumb:r(s)},null,8,["breadcrumb"]),v("div",x,[t(d,{class:"sidebar",sections:r(i)},null,8,["sections"]),t(c)])],64)}}});const J=I(k,[["__scopeId","data-v-7eef90b7"]]);export{J as default};
//# sourceMappingURL=Organization.3aa4ab34.js.map
