import{q as t,b as s,c}from"./registerWidgets.29e41a54.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="59c52c6e-7113-4197-a4b5-8ea1c2b02673",e._sentryDebugIdIdentifier="sentry-dbid-59c52c6e-7113-4197-a4b5-8ea1c2b02673")}catch{}})();const o={},r={class:"organization-settings"};function a(e,n){return s(),c("div",r,"Organization settings")}const f=t(o,[["render",a]]);export{f as default};
//# sourceMappingURL=OrganizationSettings.a154435b.js.map
