import{q as r,a,b as i,t as c,f as d,g as p,_,h as u,k as l,T as f,P as h,C as g,M as y,s as m,i as b,j as s,l as w,m as v,n as k}from"./registerWidgets.bbbd3e16.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="a910d794-362f-4556-a8ba-c59a6d017504",e._sentryDebugIdIdentifier="sentry-dbid-a910d794-362f-4556-a8ba-c59a6d017504")}catch{}})();const I={};function x(e,t){const o=a("router-view");return i(),c(o,{style:{"min-height":"100vh","box-sizing":"border-box",width:"100%"}})}const A=r(I,[["render",x]]),n=d({history:p("/"),routes:[{path:"/:path(.*)*",name:"player",component:()=>_(()=>import("./Player.f26bf724.js"),["assets/Player.f26bf724.js","assets/index.262dc502.js","assets/registerWidgets.bbbd3e16.js","assets/registerWidgets.a7e6ab4f.css","assets/log.b6b87e18.js","assets/broker.908bff0a.js","assets/passwordlessManager.2d127f26.js","assets/icons.3f47812d.js","assets/ActionButton.vue_vue_type_script_setup_true_lang.e3c03d38.js","assets/Passwordless.3632cd2d.js","assets/CircularLoading.85040470.js","assets/CircularLoading.f81b57b4.css","assets/Passwordless.2b58e538.css","assets/executeJs.0c209555.js","assets/PlayerNavbar.07d2a141.js","assets/PlayerNavbar.1542e7ca.css","assets/WidgetsFrame.6ac0484b.js","assets/colors.2ae65073.js","assets/WidgetsFrame.701a818b.css","assets/Modal.2efbfa6a.js","assets/Modal.5aaf8eba.css","assets/executeJs.b0d1ede9.css","assets/broker.f87ad36d.css","assets/DashPlayer.ff17fdb5.js","assets/runnerData.64ece65b.js","assets/DashPlayer.a2bc20b8.css","assets/asyncComputed.ad67be0e.js","assets/Player.32200e3c.css"])}],scrollBehavior(e){if(e.hash)return{el:e.hash}}}),D=()=>{window.__dashBrokerHost="ws://localhost:8001";const e=u({render:()=>l(A)});f.init(),e.use(n),e.use(h),e.mount("#app"),e.component("VSelect",g),e.component("Markdown",y),e.component("Message",m),b(e,n),s(e,w),s(e,v),s(e,k)};D();
//# sourceMappingURL=player.49395850.js.map
