import{P as n}from"./Passwordless.aeb71179.js";import{N as r}from"./Navbar.025bc9eb.js";import{d,b as i,c,e as t,H as _,q as p}from"./registerWidgets.29ceb1a3.js";import{M as m}from"./member.ae4927db.js";import"./CircularLoading.f0b3522c.js";import"./lottie.dc9b75c3.js";import"./icons.3ddac2d4.js";import"./passwordlessManager.68f14bfc.js";import"./logo.084e5d7c.js";import"./asyncComputed.9ed582d0.js";import"./gateway.59946eef.js";import"./activeRecord.ab1afca6.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="cbabb176-9635-449f-9a1a-aa6b39d48d4d",e._sentryDebugIdIdentifier="sentry-dbid-cbabb176-9635-449f-9a1a-aa6b39d48d4d")}catch{}})();const b={class:"login"},f=d({__name:"Login",setup(e){const o=_();async function s(a){await m.login(),o.push({name:"home"})}return(a,l)=>(i(),c("div",b,[t(r,{class:"nav"}),t(n,{class:"passwordless",onDone:s})]))}});const N=p(f,[["__scopeId","data-v-c9b2b4e6"]]);export{N as default};
//# sourceMappingURL=Login.fbb8e772.js.map
