.triangle[data-v-7ca41e33]{width:0;height:0;border-style:solid;border-width:4px 4px 0 4px;border-color:black transparent transparent transparent}[data-v-04d82775]:root{--main-font-family: DM Sans, sans-serif}[data-v-04d82775]:root{--abstra-neutral-color: #bbb;--abstra-primary-color: #ffee56;--abstra-dark-text-color: #1b1b23;--abstra-normal-text-color: #414a58;--abstra-main-color-dark: #343b46;--abstra-main-color-light: #ffd84c;--abstra-secondary-color-dark: #4c5767;--abstra-secondary-color-light: #feab4c;--abstra-background-base: #f9fafb;--abstra-main-color-blue: #2479df}.box-shadow-button[data-v-04d82775]{display:flex;flex-direction:row;justify-content:center;align-items:center;padding:10px 12px;border-radius:4px;user-select:none;cursor:pointer;transition:box-shadow .3s ease-out;font-size:10px;line-height:1.4;color:#414a58;border:none;background:transparent;gap:6px}.box-shadow-button[data-v-04d82775]:hover,.box-shadow-button[data-v-04d82775]:active,.box-shadow-button.active[data-v-04d82775]{box-shadow:inset 1px 1px 2px #0000001a}[data-v-c4232f59]:root{--main-font-family: DM Sans, sans-serif}[data-v-c4232f59]:root{--abstra-neutral-color: #bbb;--abstra-primary-color: #ffee56;--abstra-dark-text-color: #1b1b23;--abstra-normal-text-color: #414a58;--abstra-main-color-dark: #343b46;--abstra-main-color-light: #ffd84c;--abstra-secondary-color-dark: #4c5767;--abstra-secondary-color-light: #feab4c;--abstra-background-base: #f9fafb;--abstra-main-color-blue: #2479df}.dropdown-menu[data-v-c4232f59]{position:relative}.title[data-v-c4232f59] span{text-transform:uppercase;margin-right:8px}.title[data-v-c4232f59] .icon{transition:transform .3s ease-out}.title.active[data-v-c4232f59] .icon{transform:rotate(180deg)}.options[data-v-c4232f59]{position:absolute;left:0;bottom:0;transform:translateY(calc(100% + 4px));padding:8px 0;border-radius:4px;border:1px solid #f3f4f6;box-shadow:0 0 15px #0000000a;gap:5px;display:inline-flex;flex-direction:column;background:#fff;z-index:1}.options .line[data-v-c4232f59]{width:100%;height:1px;background:#edeff2;margin:4px 0}.options .option[data-v-c4232f59]{display:inline-flex;padding:4px 14px;user-select:none;cursor:pointer;align-items:center;transition:background .3s ease-out}.options .option span[data-v-c4232f59]{margin-left:10px;font-size:12px;color:#6d7c93;white-space:nowrap}.options .option[data-v-c4232f59]:hover{background:#edeff2}.options .option:hover span[data-v-c4232f59]{color:#5a677a}.options .option[data-v-c4232f59]:hover path{fill:#5a677a}.options .option[data-v-c4232f59]:active{background:#dbdee4}.options .option:active span[data-v-c4232f59]{color:#414a58}.options .option[data-v-c4232f59]:active path{fill:#414a58}.options .option.dangerous[data-v-c4232f59] path{fill:#d35249}.options .option.dangerous span[data-v-c4232f59]{color:#d35249}.options .option.dangerous[data-v-c4232f59]:hover{background:rgba(211,82,73,.1)}.options .option.dangerous[data-v-c4232f59]:active{background:rgba(211,82,73,.2)}
