import{_ as y}from"./logo.084e5d7c.js";import{q as i,b as s,c as o,O as u,Q as p,x as t,d as m,H as x,a as $,z as c,N as b,e as n,w as g,S as v,F as L,L as N,D as C,ao as I}from"./registerWidgets.88d12ae1.js";import{p as l}from"./passwordlessManager.a5c71e7e.js";import{a as B}from"./asyncComputed.0bf661db.js";const S={},h=e=>(u("data-v-439be421"),e=e(),p(),e),w={class:"logo"},V=h(()=>t("img",{class:"logo-img",src:y,alt:"Abstra cloud logo"},null,-1)),A=h(()=>t("span",null,"Abstra Cloud",-1)),D=[V,A];function F(e,_){return s(),o("div",w,D)}const R=i(S,[["render",F],["__scopeId","data-v-439be421"]]),U={key:0},q={key:1,class:"logged"},z={class:"author-email"},E={key:2},H=m({__name:"LoginBlock",setup(e){const _=x(),{result:r,loading:a,refetch:d}=B(async()=>l.getUser());function f(){l.removeUser(),d(),_.push({name:"login"})}return(P,W)=>{const k=$("router-link");return c(a)?(s(),o("div",U,"loading...")):c(r)?(s(),o("div",q,[t("span",z,b(c(r).claims.email),1),t("button",{class:"btn",onClick:f},"Logout")])):(s(),o("div",E,[n(k,{class:"btn",to:"/login"},{default:g(()=>[v("Login")]),_:1})]))}}});const M=i(H,[["__scopeId","data-v-6c08207b"]]),O=e=>(u("data-v-cf48b8cc"),e=e(),p(),e),Q={class:"nav"},T={class:"left"},j={key:0,class:"breadcrumb-container"},G=O(()=>t("span",{class:"divider"},">",-1)),J={class:"right"},K=m({__name:"Navbar",props:{breadcrumb:null},setup(e){return(_,r)=>(s(),o("nav",Q,[t("div",T,[n(R),e.breadcrumb?(s(),o("div",j,[(s(!0),o(L,null,N(e.breadcrumb,(a,d)=>(s(),o("span",{key:d,class:"breadcrumb-item"},[n(c(I),{class:"breadcrumb-link",to:a.path},{default:g(()=>[v(b(a.label),1)]),_:2},1032,["to"]),G]))),128))])):C("",!0)]),t("div",J,[n(M)])]))}});const se=i(K,[["__scopeId","data-v-cf48b8cc"]]);export{se as N};
//# sourceMappingURL=Navbar.9e3b85e1.js.map
