import{P as n}from"./Passwordless.1c4f72d4.js";import{N as r}from"./Navbar.0ec3decd.js";import{d as c,b as d,c as i,e as t,H as _,q as p}from"./registerWidgets.fce18b61.js";import{M as m}from"./member.5915ce2c.js";import"./CircularLoading.01aaac49.js";import"./lottie.84b3db69.js";import"./icons.99afd58c.js";import"./passwordlessManager.2cd33479.js";import"./logo.084e5d7c.js";import"./asyncComputed.aceaab2d.js";import"./gateway.6f3c5fa6.js";import"./activeRecord.5ca93a47.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="a3c616aa-e180-4aed-ac7d-4b8ceebbfb76",e._sentryDebugIdIdentifier="sentry-dbid-a3c616aa-e180-4aed-ac7d-4b8ceebbfb76")}catch{}})();const b={class:"login"},f=c({__name:"Login",setup(e){const o=_();async function s(a){await m.login(),o.push({name:"home"})}return(a,l)=>(d(),i("div",b,[t(r,{class:"nav"}),t(n,{class:"passwordless",onDone:s})]))}});const N=p(f,[["__scopeId","data-v-c9b2b4e6"]]);export{N as default};
//# sourceMappingURL=Login.7dd00994.js.map
