import{q as t,b as s,c as a}from"./registerWidgets.68b4d727.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="47f2c13b-2861-4565-9a1a-a58feebccd95",e._sentryDebugIdIdentifier="sentry-dbid-47f2c13b-2861-4565-9a1a-a58feebccd95")}catch{}})();const c={},o={class:"organization-settings"};function r(e,n){return s(),a("div",o,"Organization settings")}const f=t(c,[["render",r]]);export{f as default};
//# sourceMappingURL=OrganizationSettings.2b05f44f.js.map
