import{p as o,a as r,b as a,q as n,f as i,g as p,_ as c,h as _,j as h,T as u,P as d,C as l,M as m,s as g,i as t,k as v,l as w,m as f}from"./registerWidgets.990552e9.js";const k={};function y(e,W){const s=r("router-view");return a(),n(s,{style:{"min-height":"100vh","box-sizing":"border-box",width:"100%"}})}const b=o(k,[["render",y]]),x=i({history:p("/"),routes:[{path:"/:path(.*)*",name:"player",component:()=>c(()=>import("./Player.c57f65bb.js"),["assets/Player.c57f65bb.js","assets/index.c13cb307.js","assets/registerWidgets.990552e9.js","assets/registerWidgets.a7e6ab4f.css","assets/log.90d86245.js","assets/broker.2a35084b.js","assets/passwordlessManager.43e7eeb6.js","assets/icons.d4e872e2.js","assets/Passwordless.62d0ea6a.js","assets/CircularLoading.b7a09562.js","assets/CircularLoading.f81b57b4.css","assets/Passwordless.2b58e538.css","assets/WidgetsFrame.f35d659d.js","assets/colors.5631539e.js","assets/colors.1542e7ca.css","assets/Modal.180a3c02.js","assets/Modal.5aaf8eba.css","assets/WidgetsFrame.a59f1aee.css","assets/broker.f87ad36d.css","assets/DashPlayer.bd373ba5.js","assets/runnerData.eb6270ce.js","assets/DashPlayer.a2bc20b8.css","assets/asyncComputed.5a7faf96.js","assets/Player.32200e3c.css"])}],scrollBehavior(e){if(e.hash)return{el:e.hash}}}),A=()=>{window.__dashBrokerHost="ws://localhost:8001";const e=_({render:()=>h(b)});u.init(),e.use(x),e.use(d),e.mount("#app"),e.component("VSelect",l),e.component("Markdown",m),e.component("Message",g),t(e,v),t(e,w),t(e,f)};A();
//# sourceMappingURL=player.708bbfab.js.map
