import{d as o,b as s,c,p as _}from"./registerWidgets.04dc761e.js";const n=["href"],a=o({__name:"DocsButton",props:{path:null},setup(e){return(p,r)=>{var t;return s(),c("a",{class:"docs-button",href:`https://docs.abstra.io/${(t=e.path)!=null?t:""}`,target:"_blank"}," Docs ",8,n)}}});const d=_(a,[["__scopeId","data-v-9fec5678"]]);export{d as D};
//# sourceMappingURL=DocsButton.5c9fcb4f.js.map
