import{x as a}from"./icons.54ab2234.js";import{d as r,a as c,b as i,c as d,e as _,z as l,S as u,q as p}from"./registerWidgets.eddc32f4.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="39312224-7e01-4999-a06b-3c35d5474629",e._sentryDebugIdIdentifier="sentry-dbid-39312224-7e01-4999-a06b-3c35d5474629")}catch{}})();const f=r({__name:"BackButton",emits:["exitFullscreenPreview"],setup(e,{emit:t}){return(o,n)=>{const s=c("icon");return i(),d("button",{class:"back-btn",onClick:n[0]||(n[0]=b=>t("exitFullscreenPreview"))},[_(s,{class:"icon",path:l(a),width:"20",height:"20",fill:"#5A677A"},null,8,["path"]),u(" Editor ")])}}});const w=p(f,[["__scopeId","data-v-eaeb3a6e"]]);export{w as B};
//# sourceMappingURL=BackButton.cc75430c.js.map
