import{u as c}from"./icons.b993259e.js";import{d,J as u,H as i,a as p,b as _,c as l,e as f,z as m,S as y,q as b}from"./registerWidgets.f021c1a4.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="58d6ea8f-e9c0-4ae9-8968-2f724d3481a8",e._sentryDebugIdIdentifier="sentry-dbid-58d6ea8f-e9c0-4ae9-8968-2f724d3481a8")}catch{}})();const v=d({__name:"PreviewButton",props:{model:null},setup(e){const t=e,o=u(),s=i(),a=()=>{const n=o.query;s.push({path:`/_editor/${t.model.routeName}/${encodeURIComponent(t.model.path)}/preview`,query:n})};return(n,w)=>{const r=p("icon");return _(),l("button",{class:"preview-button",onClick:a},[f(r,{class:"icon",path:m(c),width:"20",height:"20",fill:"#5A677A"},null,8,["path"]),y(" Preview ")])}}});const I=b(v,[["__scopeId","data-v-4b4c109d"]]);export{I as P};
//# sourceMappingURL=PreviewButton.ced8e1ec.js.map
