import{P as n}from"./Passwordless.e2d42681.js";import{N as r}from"./Navbar.85024c61.js";import{d as i,b as c,c as d,e as t,H as _,q as p}from"./registerWidgets.966858c5.js";import{M as f}from"./member.fe20dbda.js";import"./CircularLoading.11f239a9.js";import"./lottie.91935b30.js";import"./icons.e22fc21e.js";import"./passwordlessManager.7ff47fc0.js";import"./logo.084e5d7c.js";import"./asyncComputed.af01c07f.js";import"./gateway.e0302561.js";import"./activeRecord.250eaea9.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="a1a1efa4-3a93-4252-96ab-4cc85aef25e3",e._sentryDebugIdIdentifier="sentry-dbid-a1a1efa4-3a93-4252-96ab-4cc85aef25e3")}catch{}})();const m={class:"login"},l=i({__name:"Login",setup(e){const o=_();async function s(a){await f.login(),o.push({name:"home"})}return(a,u)=>(c(),d("div",m,[t(r,{class:"nav"}),t(n,{class:"passwordless",onDone:s})]))}});const N=p(l,[["__scopeId","data-v-c9b2b4e6"]]);export{N as default};
//# sourceMappingURL=Login.147dac94.js.map
