import{P as r}from"./Passwordless.bf03ab53.js";import{N as a}from"./Navbar.8af6e159.js";import{d as i,b as c,c as d,e as t,H as _,q as p}from"./registerWidgets.68b4d727.js";import{M as m}from"./member.ae00d95c.js";import"./CircularLoading.d7ae4d10.js";import"./lottie.d1957a7e.js";import"./icons.ef86ff2e.js";import"./passwordlessManager.a7d5c3a4.js";import"./logo.084e5d7c.js";import"./asyncComputed.93878fc8.js";import"./gateway.8f8e2838.js";import"./activeRecord.65858c58.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="35b66e8d-1497-412c-ab6c-e59b938e6be8",e._sentryDebugIdIdentifier="sentry-dbid-35b66e8d-1497-412c-ab6c-e59b938e6be8")}catch{}})();const b={class:"login"},l=i({__name:"Login",setup(e){const o=_();async function s(n){await m.login(),o.push({name:"home"})}return(n,f)=>(c(),d("div",b,[t(a,{class:"nav"}),t(r,{class:"passwordless",onDone:s})]))}});const N=p(l,[["__scopeId","data-v-c9b2b4e6"]]);export{N as default};
//# sourceMappingURL=Login.9ba94b0b.js.map
