import{L as t}from"./lottie.314baab9.js";import{d as a,r,o as s,b as d,c,x as i,B as _,q as l}from"./registerWidgets.2bf05ebf.js";(function(){try{var n=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(n._sentryDebugIds=n._sentryDebugIds||{},n._sentryDebugIds[e]="15dfe377-44cc-4486-931a-c0ec23451cf6",n._sentryDebugIdIdentifier="sentry-dbid-15dfe377-44cc-4486-931a-c0ec23451cf6")}catch{}})();const u={class:"container"},f=a({__name:"LoadingIndicator",setup(n){const e=r(null);return s(()=>{!e.value||t.loadAnimation({container:e.value,renderer:"svg",loop:!0,autoplay:!0,path:"/circularLoading.json"})}),(o,p)=>(d(),c("div",u,[i("div",{ref_key:"animation",ref:e,class:"animation"},null,512),_(o.$slots,"default",{},void 0,!0)]))}});const m=l(f,[["__scopeId","data-v-c30401d8"]]);export{m as L};
//# sourceMappingURL=LoadingIndicator.0bf264ad.js.map
