import{q as t,b as s,c}from"./registerWidgets.29ceb1a3.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="9487210f-0147-4c95-bcec-abb9a83fffbb",e._sentryDebugIdIdentifier="sentry-dbid-9487210f-0147-4c95-bcec-abb9a83fffbb")}catch{}})();const o={},r={class:"organization-settings"};function a(e,n){return s(),c("div",r,"Organization settings")}const d=t(o,[["render",a]]);export{d as default};
//# sourceMappingURL=OrganizationSettings.dff0cd0a.js.map
