import{q as r,a,b as i,t as c,f as p,g as _,_ as d,h as u,k as f,T as l,P as h,C as b,M as g,s as y,i as m,j as s,l as w,m as v,n as k}from"./registerWidgets.80830a62.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="6f684a90-f9c9-47e2-ab28-5b3173f7a448",e._sentryDebugIdIdentifier="sentry-dbid-6f684a90-f9c9-47e2-ab28-5b3173f7a448")}catch{}})();const I={};function x(e,t){const o=a("router-view");return i(),c(o,{style:{"min-height":"100vh","box-sizing":"border-box",width:"100%"}})}const A=r(I,[["render",x]]),n=p({history:_("/"),routes:[{path:"/:path(.*)*",name:"player",component:()=>d(()=>import("./Player.573d3a9a.js"),["assets/Player.573d3a9a.js","assets/index.9089c8c2.js","assets/registerWidgets.80830a62.js","assets/registerWidgets.448db7e9.css","assets/log.3ccd8497.js","assets/broker.6a85f534.js","assets/passwordlessManager.65c1d475.js","assets/icons.96376736.js","assets/ActionButton.vue_vue_type_script_setup_true_lang.f332c731.js","assets/Passwordless.e6779d6e.js","assets/CircularLoading.dfc9e798.js","assets/lottie.ab5349ef.js","assets/CircularLoading.f81b57b4.css","assets/Passwordless.2b58e538.css","assets/executeJs.74f241ca.js","assets/PlayerNavbar.1f5ef7b9.js","assets/PlayerNavbar.1542e7ca.css","assets/WidgetsFrame.fba80f3e.js","assets/colors.8b04d8aa.js","assets/WidgetsFrame.701a818b.css","assets/Modal.75286ba0.js","assets/Modal.5aaf8eba.css","assets/executeJs.b0d1ede9.css","assets/broker.f87ad36d.css","assets/DashPlayer.572466ef.js","assets/runnerData.fe559a1a.js","assets/DashPlayer.a2bc20b8.css","assets/asyncComputed.7fd138fd.js","assets/Player.32200e3c.css"])}],scrollBehavior(e){if(e.hash)return{el:e.hash}}}),D=()=>{window.__dashBrokerHost="ws://localhost:8001";const e=u({render:()=>f(A)});l.init(),e.use(n),e.use(h),e.mount("#app"),e.component("VSelect",b),e.component("Markdown",g),e.component("Message",y),m(e,n),s(e,w),s(e,v),s(e,k)};D();
//# sourceMappingURL=player.7cf0d49b.js.map
