import{x as a}from"./icons.b931f659.js";import{d as c,a as r,b,c as i,e as d,z as _,S as l,q as u}from"./registerWidgets.29e41a54.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="b3276b3b-a95b-4c40-bb8b-e6c88b7b1ec9",e._sentryDebugIdIdentifier="sentry-dbid-b3276b3b-a95b-4c40-bb8b-e6c88b7b1ec9")}catch{}})();const p=c({__name:"BackButton",emits:["exitFullscreenPreview"],setup(e,{emit:t}){return(o,n)=>{const s=r("icon");return b(),i("button",{class:"back-btn",onClick:n[0]||(n[0]=f=>t("exitFullscreenPreview"))},[d(s,{class:"icon",path:_(a),width:"20",height:"20",fill:"#5A677A"},null,8,["path"]),l(" Editor ")])}}});const w=u(p,[["__scopeId","data-v-eaeb3a6e"]]);export{w as B};
//# sourceMappingURL=BackButton.cbcf7cc6.js.map
