import{P as a}from"./Passwordless.ada2efe6.js";import{N as r}from"./Navbar.4dd52c8a.js";import{d as n,b as _,c as i,e as o,H as p,q as c}from"./registerWidgets.ba12cd54.js";import{M as m}from"./member.1ae51d0f.js";import"./CircularLoading.79e96d11.js";import"./icons.ea1ef9e9.js";import"./passwordlessManager.a5941d42.js";import"./logo.084e5d7c.js";import"./asyncComputed.3e2c3bcb.js";import"./utils.a13b462f.js";import"./pubsub.a0411919.js";const d={class:"login"},l=n({__name:"Login",setup(f){const e=p();async function s(t){await m.login(),e.push({name:"home"})}return(t,u)=>(_(),i("div",d,[o(r,{class:"nav"}),o(a,{class:"passwordless",onDone:s})]))}});const B=c(l,[["__scopeId","data-v-5114fe52"]]);export{B as default};
//# sourceMappingURL=Login.b2903a3c.js.map
