import{_ as y}from"./logo.084e5d7c.js";import{p as i,b as s,c as o,N as u,O as p,v as t,d as m,G as $,a as x,y as c,L as b,e as n,w as g,R as v,F as L,K as N,B,az as C}from"./registerWidgets.04dc761e.js";import{p as l}from"./passwordlessManager.271a8058.js";import{a as I}from"./asyncComputed.e0f43af3.js";const w={},h=e=>(u("data-v-439be421"),e=e(),p(),e),S={class:"logo"},V=h(()=>t("img",{class:"logo-img",src:y,alt:"Abstra cloud logo"},null,-1)),R=h(()=>t("span",null,"Abstra Cloud",-1)),A=[V,R];function F(e,_){return s(),o("div",S,A)}const U=i(w,[["render",F],["__scopeId","data-v-439be421"]]),z={key:0},D={key:1,class:"logged"},E={class:"author-email"},G={key:2},K=m({__name:"LoginBlock",setup(e){const _=$(),{result:r,loading:a,refetch:d}=I(async()=>l.getUser());function f(){l.removeUser(),d(),_.push({name:"login"})}return(Q,W)=>{const k=x("router-link");return c(a)?(s(),o("div",z,"loading...")):c(r)?(s(),o("div",D,[t("span",E,b(c(r).claims.email),1),t("button",{class:"btn",onClick:f},"Logout")])):(s(),o("div",G,[n(k,{class:"btn",to:"/login"},{default:g(()=>[v("Login")]),_:1})]))}}});const M=i(K,[["__scopeId","data-v-6c08207b"]]),O=e=>(u("data-v-cf48b8cc"),e=e(),p(),e),T={class:"nav"},j={class:"left"},q={key:0,class:"breadcrumb-container"},H=O(()=>t("span",{class:"divider"},">",-1)),J={class:"right"},P=m({__name:"Navbar",props:{breadcrumb:null},setup(e){return(_,r)=>(s(),o("nav",T,[t("div",j,[n(U),e.breadcrumb?(s(),o("div",q,[(s(!0),o(L,null,N(e.breadcrumb,(a,d)=>(s(),o("span",{key:d,class:"breadcrumb-item"},[n(c(C),{class:"breadcrumb-link",to:a.path},{default:g(()=>[v(b(a.label),1)]),_:2},1032,["to"]),H]))),128))])):B("",!0)]),t("div",J,[n(M)])]))}});const se=i(P,[["__scopeId","data-v-cf48b8cc"]]);export{se as N};
//# sourceMappingURL=Navbar.3dcea4af.js.map
