[data-v-580769d7]:root{--main-font-family: DM Sans, sans-serif}[data-v-580769d7]:root{--abstra-neutral-color: #bbb;--abstra-primary-color: #ffee56;--abstra-dark-text-color: #1b1b23;--abstra-normal-text-color: #414a58;--abstra-main-color-dark: #343b46;--abstra-main-color-light: #ffd84c;--abstra-secondary-color-dark: #4c5767;--abstra-secondary-color-light: #feab4c;--abstra-background-base: #f9fafb;--abstra-main-color-blue: #d14056}.organization[data-v-580769d7]{display:flex;max-width:100vw;box-sizing:border-box;gap:20px;padding:30px 20px;height:fit-content}.organization .sidebar[data-v-580769d7]{position:sticky;top:30px}
