import{d as r,r as i,o as l,a3 as u,b as c,c as f,N as b,ad as y}from"./registerWidgets.7cf0d33e.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="a0d1abf2-ec25-4680-83dd-b17464a04e0e",e._sentryDebugIdIdentifier="sentry-dbid-a0d1abf2-ec25-4680-83dd-b17464a04e0e")}catch{}})();const g=r({__name:"ActionButton",props:{action:null},emits:["next"],setup(e,{emit:n}){const o=e,s=i(null);l(()=>{s.value&&o.action.setElement(s.value),u.addAction(o.action)});const a=()=>n("next");return(m,t)=>(c(),f("button",{ref_key:"element",ref:s,class:"next-button",onClick:t[0]||(t[0]=d=>a()),onKeydown:t[1]||(t[1]=y(d=>a(),["enter"]))},b(e.action.name),545))}});export{g as _};
//# sourceMappingURL=ActionButton.vue_vue_type_script_setup_true_lang.a07ae91e.js.map
