import{q as t,b as s,c as o}from"./registerWidgets.c33434b6.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="5c30a702-3e14-4e38-9d79-909ff612e020",e._sentryDebugIdIdentifier="sentry-dbid-5c30a702-3e14-4e38-9d79-909ff612e020")}catch{}})();const r={},i={class:"organization-settings"};function a(e,n){return s(),o("div",i,"Organization settings")}const f=t(r,[["render",a]]);export{f as default};
//# sourceMappingURL=OrganizationSettings.8db0ccba.js.map
