import{q as t,b as s,c as a}from"./registerWidgets.966858c5.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="e26f46b9-a895-4ed8-881c-aa6ac7cd3108",e._sentryDebugIdIdentifier="sentry-dbid-e26f46b9-a895-4ed8-881c-aa6ac7cd3108")}catch{}})();const c={},o={class:"organization-settings"};function r(e,n){return s(),a("div",o,"Organization settings")}const f=t(c,[["render",r]]);export{f as default};
//# sourceMappingURL=OrganizationSettings.7211a11b.js.map
