import{L as a}from"./lottie.adcbdb1d.js";import{d as t,r as d,o as r,b as s,c,x as i,B as _,q as l}from"./registerWidgets.7cf0d33e.js";(function(){try{var n=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(n._sentryDebugIds=n._sentryDebugIds||{},n._sentryDebugIds[e]="81df4b91-dcc8-4baa-91dc-3b2413ecc861",n._sentryDebugIdIdentifier="sentry-dbid-81df4b91-dcc8-4baa-91dc-3b2413ecc861")}catch{}})();const u={class:"container"},f=t({__name:"LoadingIndicator",setup(n){const e=d(null);return r(()=>{!e.value||a.loadAnimation({container:e.value,renderer:"svg",loop:!0,autoplay:!0,path:"/circularLoading.json"})}),(o,p)=>(s(),c("div",u,[i("div",{ref_key:"animation",ref:e,class:"animation"},null,512),_(o.$slots,"default",{},void 0,!0)]))}});const g=l(f,[["__scopeId","data-v-c30401d8"]]);export{g as L};
//# sourceMappingURL=LoadingIndicator.8661078b.js.map
