import{q as r,a,b as i,t as c,f as p,g as _,_ as d,h as u,k as l,T as f,P as h,C as b,M as g,s as y,i as m,j as s,l as w,m as v,n as k}from"./registerWidgets.8e2e133d.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="43e7ba93-9442-4cea-8254-b5f9023c3085",e._sentryDebugIdIdentifier="sentry-dbid-43e7ba93-9442-4cea-8254-b5f9023c3085")}catch{}})();const I={};function x(e,t){const o=a("router-view");return i(),c(o,{style:{"min-height":"100vh","box-sizing":"border-box",width:"100%"}})}const A=r(I,[["render",x]]),n=p({history:_("/"),routes:[{path:"/:path(.*)*",name:"player",component:()=>d(()=>import("./Player.92a58e0a.js"),["assets/Player.92a58e0a.js","assets/index.a245f875.js","assets/registerWidgets.8e2e133d.js","assets/registerWidgets.448db7e9.css","assets/log.ab29b85c.js","assets/broker.1b95b3d3.js","assets/passwordlessManager.cb9f88a0.js","assets/icons.35c960d1.js","assets/ActionButton.vue_vue_type_script_setup_true_lang.20bd37d2.js","assets/Passwordless.399a4808.js","assets/CircularLoading.b144822c.js","assets/lottie.7a1c6d39.js","assets/CircularLoading.f81b57b4.css","assets/Passwordless.2b58e538.css","assets/executeJs.0d999a1c.js","assets/PlayerNavbar.cf04b8e0.js","assets/PlayerNavbar.1542e7ca.css","assets/WidgetsFrame.c12866fb.js","assets/colors.351121a9.js","assets/WidgetsFrame.701a818b.css","assets/Modal.2a0bcd16.js","assets/Modal.5aaf8eba.css","assets/executeJs.b0d1ede9.css","assets/broker.f87ad36d.css","assets/DashPlayer.81cb9013.js","assets/runnerData.d93bd000.js","assets/DashPlayer.a2bc20b8.css","assets/asyncComputed.a6090ca2.js","assets/Player.32200e3c.css"])}],scrollBehavior(e){if(e.hash)return{el:e.hash}}}),D=()=>{window.__dashBrokerHost="ws://localhost:8001";const e=u({render:()=>l(A)});f.init(),e.use(n),e.use(h),e.mount("#app"),e.component("VSelect",b),e.component("Markdown",g),e.component("Message",y),m(e,n),s(e,w),s(e,v),s(e,k)};D();
//# sourceMappingURL=player.3e2e60d0.js.map
