import{q as o,a as r,b as a,t as n,f as i,g as c,_ as p,h as _,j as h,T as u,P as d,C as l,M as m,s as g,i as t,k as v,l as w,m as f}from"./registerWidgets.802bba2f.js";const k={};function y(e,W){const s=r("router-view");return a(),n(s,{style:{"min-height":"100vh","box-sizing":"border-box",width:"100%"}})}const b=o(k,[["render",y]]),x=i({history:c("/"),routes:[{path:"/:path(.*)*",name:"player",component:()=>p(()=>import("./Player.1f0f7ecd.js"),["assets/Player.1f0f7ecd.js","assets/index.7eb978ee.js","assets/registerWidgets.802bba2f.js","assets/registerWidgets.c131d556.css","assets/log.8028a717.js","assets/broker.5716bf12.js","assets/passwordlessManager.d5134797.js","assets/icons.03f7ad73.js","assets/Passwordless.50bb9805.js","assets/CircularLoading.5c7f2ad7.js","assets/CircularLoading.f81b57b4.css","assets/Passwordless.c981501a.css","assets/WidgetsFrame.8f0c7a42.js","assets/Modal.e13f7972.js","assets/Modal.5aaf8eba.css","assets/WidgetsFrame.f427edd2.css","assets/broker.b057aed3.css","assets/DashPlayer.ce674924.js","assets/runnerData.37fb2c95.js","assets/DashPlayer.f60035bd.css","assets/asyncComputed.1364aaa9.js","assets/Player.82401ce5.css"])}],scrollBehavior(e){if(e.hash)return{el:e.hash}}}),A=()=>{window.__dashBrokerHost="ws://localhost:8001";const e=_({render:()=>h(b)});u.init(),e.use(x),e.use(d),e.mount("#app"),e.component("VSelect",l),e.component("Markdown",m),e.component("Message",g),t(e,v),t(e,w),t(e,f)};A();
//# sourceMappingURL=player.2a3efb00.js.map
