import{P as r}from"./Passwordless.a3421c62.js";import{N as d}from"./Navbar.9761abf7.js";import{d as a,b as i,c,e as t,H as _,q as p}from"./registerWidgets.eddc32f4.js";import{M as f}from"./member.f4bff51a.js";import"./CircularLoading.c96bd1c9.js";import"./lottie.6d443700.js";import"./icons.54ab2234.js";import"./passwordlessManager.8b97cbcd.js";import"./logo.084e5d7c.js";import"./asyncComputed.562c187e.js";import"./gateway.7d65591c.js";import"./activeRecord.ed4e0294.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="ee4d08bd-39dd-4f20-9d6a-b71fbc01e903",e._sentryDebugIdIdentifier="sentry-dbid-ee4d08bd-39dd-4f20-9d6a-b71fbc01e903")}catch{}})();const m={class:"login"},b=a({__name:"Login",setup(e){const o=_();async function s(n){await f.login(),o.push({name:"home"})}return(n,l)=>(i(),c("div",m,[t(d,{class:"nav"}),t(r,{class:"passwordless",onDone:s})]))}});const N=p(b,[["__scopeId","data-v-c9b2b4e6"]]);export{N as default};
//# sourceMappingURL=Login.2f9b04f0.js.map
