import{S as i}from"./Sidebar.881514c1.js";import{N as c}from"./Navbar.be22e75c.js";import{F as m,G as p,H as l}from"./icons.ea1ef9e9.js";import{d as u,K as _,b,c as d,e,z as o,x as g,F as v,J as f,a as z,q as h}from"./registerWidgets.ba12cd54.js";import{a as O}from"./asyncComputed.3e2c3bcb.js";import"./utils.a13b462f.js";import{O as x}from"./organization.ffdf2ba2.js";import"./Tooltip.0dc21a61.js";import"./logo.084e5d7c.js";import"./passwordlessManager.a5941d42.js";import"./pubsub.a0411919.js";const y={class:"organization"},B=u({__name:"Organization",setup(N){const t=f().params.organizationId,{result:a}=O(()=>x.get(t)),n=_(()=>a.value?[{label:a.value.name,path:`/organizations/${a.value.id}`}]:void 0),r=[{name:"Organization",items:[{name:"Projects",icon:m,path:"projects"},{name:"Members",icon:p,path:"members"},{name:"Billing",icon:l,path:"billing",unavailable:!0}]}];return(w,C)=>{const s=z("router-view");return b(),d(v,null,[e(c,{breadcrumb:o(n)},null,8,["breadcrumb"]),g("div",y,[e(i,{class:"sidebar",sections:o(r)},null,8,["sections"]),e(s)])],64)}}});const K=h(B,[["__scopeId","data-v-6b7bb018"]]);export{K as default};
//# sourceMappingURL=Organization.873255fd.js.map
