import{M as s}from"./Modal.7746640d.js";import{d as r,v as c,r as d,b as _,c as f,e as t,w as l,F as i,a as m,x as u,q as p}from"./registerWidgets.29e41a54.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="9adf254a-f31b-42bf-a182-aade5425642c",e._sentryDebugIdIdentifier="sentry-dbid-9adf254a-f31b-42bf-a182-aade5425642c")}catch{}})();const b=["src"],y=r({__name:"Home",setup(e){const o=c({onboardingForm:""}),a=d(null);return(g,v)=>{const n=m("router-view");return _(),f(i,null,[t(n,{class:"router"}),t(s,{ref_key:"modal",ref:a},{content:l(()=>[u("iframe",{class:"form",src:o.onboardingForm},null,8,b)]),_:1},512)],64)}}});const I=p(y,[["__scopeId","data-v-8c8bc27e"]]);export{I as default};
//# sourceMappingURL=Home.02f8c5ab.js.map
