import{q as t,b as n,c as e}from"./registerWidgets.81004098.js";const s={},o={class:"organization-settings"};function a(c,i){return n(),e("div",o,"Organization settings")}const _=t(s,[["render",a]]);export{_ as default};
//# sourceMappingURL=OrganizationSettings.cfd9b8c8.js.map
