import{u as a}from"./icons.012820f9.js";import{d,J as u,H as i,a as p,b as _,c as l,e as f,z as b,S as m,q as y}from"./registerWidgets.553de467.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="c7cbd2fb-c44d-4f7e-8ee7-e87184fe6348",e._sentryDebugIdIdentifier="sentry-dbid-c7cbd2fb-c44d-4f7e-8ee7-e87184fe6348")}catch{}})();const v=d({__name:"PreviewButton",props:{model:null},setup(e){const t=e,o=u(),s=i(),c=()=>{const n=o.query;s.push({path:`/_editor/${t.model.routeName}/${encodeURIComponent(t.model.path)}/preview`,query:n})};return(n,w)=>{const r=p("icon");return _(),l("button",{class:"preview-button",onClick:c},[f(r,{class:"icon",path:b(a),width:"20",height:"20",fill:"#5A677A"},null,8,["path"]),m(" Preview ")])}}});const I=y(v,[["__scopeId","data-v-4b4c109d"]]);export{I as P};
//# sourceMappingURL=PreviewButton.d2ef36ae.js.map
