[data-v-3da8363c]:root{--main-font-family: DM Sans, sans-serif}[data-v-3da8363c]:root{--abstra-neutral-color: #bbb;--abstra-primary-color: #ffee56;--abstra-dark-text-color: #1b1b23;--abstra-normal-text-color: #414a58;--abstra-main-color-dark: #343b46;--abstra-main-color-light: #ffd84c;--abstra-secondary-color-dark: #4c5767;--abstra-secondary-color-light: #feab4c;--abstra-background-base: #f9fafb;--abstra-main-color-blue: #2479df}.buttons[data-v-3da8363c]{display:flex;flex-direction:row;width:100%;justify-content:space-between}.main-text[data-v-3da8363c]{text-align:center}.separator[data-v-3da8363c]{height:1px;width:100%;background-color:#e9ecef;margin:20px 0 30px}.cancel[data-v-3da8363c]{cursor:pointer;display:flex;flex-direction:row;justify-content:center;align-items:center;padding:8px 20px;gap:10px;border:none;border-radius:4px;font-family:DM Sans,sans-serif;color:#2479df;border:1px solid #2479df;background:transparent}.cancel[data-v-3da8363c]:hover{background:#f3f8ff}.cancel[data-v-3da8363c]:active,.cancel active[data-v-3da8363c]{background:#d6e4f7}.delete[data-v-3da8363c]{cursor:pointer;display:flex;flex-direction:row;justify-content:center;align-items:center;padding:8px 20px;gap:10px;border:none;border-radius:4px;font-family:DM Sans,sans-serif;background:#2479df;color:#fff;box-shadow:0 2px 4px #00000026}.delete[data-v-3da8363c]:hover{background:#448add;box-shadow:0 4px 12px #00000026}.delete[data-v-3da8363c]:active,.delete active[data-v-3da8363c]{background:#448add;box-shadow:inset 0 4px 4px #0000000f}.delete[data-v-3da8363c]:only-child{margin:0 auto}
