import{q as a,a as r,b as i,t as c,f as d,g as p,_,h as u,k as l,T as f,P as h,C as b,M as g,s as y,i as m,j as s,l as w,m as v,n as k}from"./registerWidgets.f021c1a4.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="acece87a-ad1b-472a-a38b-c6015ef8032c",e._sentryDebugIdIdentifier="sentry-dbid-acece87a-ad1b-472a-a38b-c6015ef8032c")}catch{}})();const I={};function x(e,t){const o=r("router-view");return i(),c(o,{style:{"min-height":"100vh","box-sizing":"border-box",width:"100%"}})}const A=a(I,[["render",x]]),n=d({history:p("/"),routes:[{path:"/:path(.*)*",name:"player",component:()=>_(()=>import("./Player.5ca638e5.js"),["assets/Player.5ca638e5.js","assets/index.4db2f83c.js","assets/registerWidgets.f021c1a4.js","assets/registerWidgets.448db7e9.css","assets/log.76987186.js","assets/broker.2985690c.js","assets/passwordlessManager.60015512.js","assets/icons.b993259e.js","assets/ActionButton.vue_vue_type_script_setup_true_lang.db19569b.js","assets/Passwordless.41457a61.js","assets/CircularLoading.403df380.js","assets/lottie.61fc86ea.js","assets/CircularLoading.f81b57b4.css","assets/Passwordless.2b58e538.css","assets/executeJs.d39ce091.js","assets/PlayerNavbar.b9e39d0d.js","assets/PlayerNavbar.1542e7ca.css","assets/WidgetsFrame.38d6628f.js","assets/colors.f679b0a6.js","assets/WidgetsFrame.701a818b.css","assets/Modal.05754801.js","assets/Modal.5aaf8eba.css","assets/executeJs.b0d1ede9.css","assets/broker.f87ad36d.css","assets/DashPlayer.d250bbd5.js","assets/runnerData.215fc732.js","assets/DashPlayer.a2bc20b8.css","assets/asyncComputed.99b3d376.js","assets/Player.32200e3c.css"])}],scrollBehavior(e){if(e.hash)return{el:e.hash}}}),D=()=>{window.__dashBrokerHost="ws://localhost:8001";const e=u({render:()=>l(A)});f.init(),e.use(n),e.use(h),e.mount("#app"),e.component("VSelect",b),e.component("Markdown",g),e.component("Message",y),m(e,n),s(e,w),s(e,v),s(e,k)};D();
//# sourceMappingURL=player.ae42374f.js.map
