import{r as u,K as f,R as v}from"./registerWidgets.bbbd3e16.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="1fed87e6-b1ed-46ee-8278-293e506f7617",e._sentryDebugIdIdentifier="sentry-dbid-1fed87e6-b1ed-46ee-8278-293e506f7617")}catch{}})();const y=e=>{const t=u(Date.now()),l=u(!0),r=u(null),a=u(null),o=f(()=>(t.value,e())),s=n=>{r.value=n,a.value=null,l.value=!1},c=n=>{a.value=n,r.value=null,l.value=!1},d=()=>{t.value=Date.now()};return v(()=>o.value,()=>{r.value=null,l.value=!0,o.value.then(s).catch(n=>{console.error(n),c(n)})}),o.value.then(s),{result:r,loading:l,error:a,refetch:d}};export{y as a};
//# sourceMappingURL=asyncComputed.ad67be0e.js.map
