import{P as a}from"./Passwordless.3632cd2d.js";import{N as r}from"./Navbar.31374668.js";import{d,b as c,c as i,e as t,H as _,q as p}from"./registerWidgets.bbbd3e16.js";import{M as f}from"./member.a2d40046.js";import"./CircularLoading.85040470.js";import"./icons.3f47812d.js";import"./passwordlessManager.2d127f26.js";import"./logo.084e5d7c.js";import"./asyncComputed.ad67be0e.js";import"./gateway.d8ce80c3.js";import"./activeRecord.9842b68f.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="a9defd76-cbd4-4cd3-ba36-7af2cf155686",e._sentryDebugIdIdentifier="sentry-dbid-a9defd76-cbd4-4cd3-ba36-7af2cf155686")}catch{}})();const m={class:"login"},l=d({__name:"Login",setup(e){const o=_();async function s(n){await f.login(),o.push({name:"home"})}return(n,u)=>(c(),i("div",m,[t(r,{class:"nav"}),t(a,{class:"passwordless",onDone:s})]))}});const M=p(l,[["__scopeId","data-v-c9b2b4e6"]]);export{M as default};
//# sourceMappingURL=Login.59e872bb.js.map
