import{P as r}from"./Passwordless.6b80be80.js";import{N as a}from"./Navbar.75e382b8.js";import{d,b as i,c,e as t,H as _,q as f}from"./registerWidgets.5bbfbb1a.js";import{M as p}from"./member.44cd6a24.js";import"./CircularLoading.fd9aaeaa.js";import"./lottie.5c7f29e3.js";import"./icons.96408396.js";import"./passwordlessManager.d271c8e1.js";import"./logo.084e5d7c.js";import"./asyncComputed.0fa43cb9.js";import"./gateway.8a51e2ca.js";import"./activeRecord.0bf8afc8.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="f16cb785-077f-409b-8bb4-7eefdd67c1fd",e._sentryDebugIdIdentifier="sentry-dbid-f16cb785-077f-409b-8bb4-7eefdd67c1fd")}catch{}})();const m={class:"login"},b=d({__name:"Login",setup(e){const o=_();async function s(n){await p.login(),o.push({name:"home"})}return(n,l)=>(i(),c("div",m,[t(a,{class:"nav"}),t(r,{class:"passwordless",onDone:s})]))}});const N=f(b,[["__scopeId","data-v-c9b2b4e6"]]);export{N as default};
//# sourceMappingURL=Login.1323ba31.js.map
