import{q as n,a as r,b as i,t as d,f as c,g as p,_,h as u,k as l,T as f,P as h,C as b,M as g,s as y,i as m,j as s,l as w,m as v,n as k}from"./registerWidgets.68b4d727.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="af84963c-78a4-4aba-9d9d-1708b0bda06a",e._sentryDebugIdIdentifier="sentry-dbid-af84963c-78a4-4aba-9d9d-1708b0bda06a")}catch{}})();const I={};function x(e,t){const o=r("router-view");return i(),d(o,{style:{"min-height":"100vh","box-sizing":"border-box",width:"100%"}})}const A=n(I,[["render",x]]),a=c({history:p("/"),routes:[{path:"/:path(.*)*",name:"player",component:()=>_(()=>import("./Player.9c3d2e3a.js"),["assets/Player.9c3d2e3a.js","assets/index.9f0d5f28.js","assets/registerWidgets.68b4d727.js","assets/registerWidgets.448db7e9.css","assets/log.088604d7.js","assets/broker.f865809f.js","assets/passwordlessManager.a7d5c3a4.js","assets/icons.ef86ff2e.js","assets/ActionButton.vue_vue_type_script_setup_true_lang.5681d83c.js","assets/Passwordless.bf03ab53.js","assets/CircularLoading.d7ae4d10.js","assets/lottie.d1957a7e.js","assets/CircularLoading.f81b57b4.css","assets/Passwordless.2b58e538.css","assets/executeJs.c67b4605.js","assets/PlayerNavbar.db54667c.js","assets/PlayerNavbar.1542e7ca.css","assets/WidgetsFrame.990b2044.js","assets/colors.8344a969.js","assets/WidgetsFrame.701a818b.css","assets/Modal.d08e28ea.js","assets/Modal.5aaf8eba.css","assets/executeJs.b0d1ede9.css","assets/broker.f87ad36d.css","assets/DashPlayer.b3abf25c.js","assets/runnerData.d765a3b7.js","assets/DashPlayer.a2bc20b8.css","assets/asyncComputed.93878fc8.js","assets/Player.32200e3c.css"])}],scrollBehavior(e){if(e.hash)return{el:e.hash}}}),D=()=>{window.__dashBrokerHost="ws://localhost:8001";const e=u({render:()=>l(A)});f.init(),e.use(a),e.use(h),e.mount("#app"),e.component("VSelect",b),e.component("Markdown",g),e.component("Message",y),m(e,a),s(e,w),s(e,v),s(e,k)};D();
//# sourceMappingURL=player.58edb264.js.map
