import{d as o,b as c,c as d,q as a}from"./registerWidgets.80830a62.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="be4b2e69-78c5-431c-8dd8-a298be559b7c",e._sentryDebugIdIdentifier="sentry-dbid-be4b2e69-78c5-431c-8dd8-a298be559b7c")}catch{}})();const _=["href"],r=o({__name:"DocsButton",props:{path:null},setup(e){return(t,n)=>{var s;return c(),d("a",{class:"docs-button",href:`https://docs.abstra.io/${(s=e.path)!=null?s:""}`,target:"_blank"}," Docs ",8,_)}}});const f=a(r,[["__scopeId","data-v-9fec5678"]]);export{f as D};
//# sourceMappingURL=DocsButton.f99d1d80.js.map
