import{_ as u}from"./logo.084e5d7c.js";import{q as _,b as s,c as a,O as r,Q as n,x as t,d as p,e as c,F as b,L as m,D as v,w as h,S as f,N as g,z as x,al as N}from"./registerWidgets.ba12cd54.js";const y={},d=e=>(r("data-v-462c26c1"),e=e(),n(),e),k={class:"logo"},I=d(()=>t("img",{class:"logo-img",src:u,alt:"Abstra cloud logo"},null,-1)),S=d(()=>t("span",null," Abstra ",-1)),L=[I,S];function $(e,l){return s(),a("div",k,L)}const w=_(y,[["render",$],["__scopeId","data-v-462c26c1"]]),V=e=>(r("data-v-ee35b98f"),e=e(),n(),e),B={class:"nav"},C={key:0,class:"breadcrumb-container"},A=V(()=>t("span",{class:"divider"},"/",-1)),D=p({__name:"Navbar",props:{breadcrumb:null},setup(e){return(l,F)=>(s(),a("nav",B,[c(w),e.breadcrumb?(s(),a("div",C,[(s(!0),a(b,null,m(e.breadcrumb,(o,i)=>(s(),a("span",{key:i,class:"breadcrumb-item"},[c(x(N),{class:"breadcrumb-link",to:o.path},{default:h(()=>[f(g(o.label),1)]),_:2},1032,["to"]),A]))),128))])):v("",!0)]))}});const E=_(D,[["__scopeId","data-v-ee35b98f"]]);export{E as N};
//# sourceMappingURL=Navbar.be22e75c.js.map
