import{d as u,K as m,b as _,t as b,w as y,z as d,J as f,O as g,Q as h,x as n,S as i,q as w}from"./registerWidgets.29e41a54.js";import{a as I}from"./asyncComputed.0126d7e4.js";import"./gateway.dfba55d6.js";import{B as x}from"./build.4656b465.js";import{C as v}from"./CrudView.3bd8b7de.js";import"./passwordlessManager.88f105f1.js";import"./activeRecord.d63d0be1.js";import"./DropdownMenu.7bd7adf5.js";import"./CircularLoading.0d1cd4f5.js";import"./Modal.7746640d.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="03d45716-5da4-4848-b21f-220eb4cbda9c",e._sentryDebugIdIdentifier="sentry-dbid-03d45716-5da4-4848-b21f-220eb4cbda9c")}catch{}})();const B=e=>(g("data-v-1b7a68a8"),e=e(),h(),e),C=B(()=>n("div",{class:"instructions"},[i(" Get started with the local editor in seconds: "),n("pre",null,`    $ pip install abstra --upgrade
    $ abstra serve ./your-project-directory
    `),i(" And you're done! Explore the local editor and start building apps. ")],-1)),S=u({__name:"Builds",setup(e){const r=f().params.projectId,{loading:c,result:l}=I(()=>x.list(r)),p=m(()=>{var o,s;return{columns:[{name:"Id"},{name:"Creation date"},{name:"Status"}],rows:(s=(o=l.value)==null?void 0:o.map(t=>({key:t.id,cells:[{text:t.id,classes:["title","centered"]},{text:t.createdAt.toLocaleString(),classes:[]},{text:t.status,classes:["centered"]}]})))!=null?s:[]}});return(o,s)=>(_(),b(v,{"entity-name":"build",loading:d(c),title:"Builds",description:"Each build is a version of your app. You can create a new build by deploying your app from the local editor.","empty-title":"No builds here yet",table:d(p)},{"empty-description":y(()=>[C]),_:1},8,["loading","table"]))}});const G=w(S,[["__scopeId","data-v-1b7a68a8"]]);export{G as default};
//# sourceMappingURL=Builds.efd047ca.js.map
