import{d as o,b as c,c as a,q as _}from"./registerWidgets.eddc32f4.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="09ab03ac-3125-41c9-99b9-95c048e96104",e._sentryDebugIdIdentifier="sentry-dbid-09ab03ac-3125-41c9-99b9-95c048e96104")}catch{}})();const r=["href"],d=o({__name:"DocsButton",props:{path:null},setup(e){return(t,n)=>{var s;return c(),a("a",{class:"docs-button",href:`https://docs.abstra.io/${(s=e.path)!=null?s:""}`,target:"_blank"}," Docs ",8,r)}}});const u=_(d,[["__scopeId","data-v-9fec5678"]]);export{u as D};
//# sourceMappingURL=DocsButton.fd4d5c2c.js.map
