import{L as t}from"./lottie.433e3d0f.js";import{d as a,r,o as d,b as s,c,x as i,B as _,q as f}from"./registerWidgets.553de467.js";(function(){try{var n=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(n._sentryDebugIds=n._sentryDebugIds||{},n._sentryDebugIds[e]="fda5869d-0708-4c8e-bc91-efb32c1f5c1b",n._sentryDebugIdIdentifier="sentry-dbid-fda5869d-0708-4c8e-bc91-efb32c1f5c1b")}catch{}})();const l={class:"container"},u=a({__name:"LoadingIndicator",setup(n){const e=r(null);return d(()=>{!e.value||t.loadAnimation({container:e.value,renderer:"svg",loop:!0,autoplay:!0,path:"/circularLoading.json"})}),(o,p)=>(s(),c("div",l,[i("div",{ref_key:"animation",ref:e,class:"animation"},null,512),_(o.$slots,"default",{},void 0,!0)]))}});const g=f(u,[["__scopeId","data-v-c30401d8"]]);export{g as L};
//# sourceMappingURL=LoadingIndicator.c7b4d86e.js.map
