import{q as r,a,b as i,t as c,f as d,g as p,_,h as u,k as l,T as b,P as f,C as h,M as g,s as y,i as m,j as s,l as w,m as v,n as k}from"./registerWidgets.ad696c68.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="bd84cee9-69f7-4598-8000-c58beb4e1d3b",e._sentryDebugIdIdentifier="sentry-dbid-bd84cee9-69f7-4598-8000-c58beb4e1d3b")}catch{}})();const I={};function x(e,t){const o=a("router-view");return i(),c(o,{style:{"min-height":"100vh","box-sizing":"border-box",width:"100%"}})}const A=r(I,[["render",x]]),n=d({history:p("/"),routes:[{path:"/:path(.*)*",name:"player",component:()=>_(()=>import("./Player.ff90ee4a.js"),["assets/Player.ff90ee4a.js","assets/index.5e96dbf3.js","assets/registerWidgets.ad696c68.js","assets/registerWidgets.a7e6ab4f.css","assets/log.812f9d15.js","assets/broker.0b03ffc6.js","assets/passwordlessManager.86ad8b48.js","assets/icons.1c1f9d53.js","assets/ActionButton.vue_vue_type_script_setup_true_lang.a0f7f94d.js","assets/Passwordless.896adb7f.js","assets/CircularLoading.1b0ceab6.js","assets/lottie.d1a83079.js","assets/CircularLoading.f81b57b4.css","assets/Passwordless.2b58e538.css","assets/executeJs.5aebf107.js","assets/PlayerNavbar.049fd037.js","assets/PlayerNavbar.1542e7ca.css","assets/WidgetsFrame.afffe632.js","assets/colors.698f0f3f.js","assets/WidgetsFrame.701a818b.css","assets/Modal.d606972f.js","assets/Modal.5aaf8eba.css","assets/executeJs.b0d1ede9.css","assets/broker.f87ad36d.css","assets/DashPlayer.f08ddbe4.js","assets/runnerData.50606928.js","assets/DashPlayer.a2bc20b8.css","assets/asyncComputed.40a67fe8.js","assets/Player.32200e3c.css"])}],scrollBehavior(e){if(e.hash)return{el:e.hash}}}),D=()=>{window.__dashBrokerHost="ws://localhost:8001";const e=u({render:()=>l(A)});b.init(),e.use(n),e.use(f),e.mount("#app"),e.component("VSelect",h),e.component("Markdown",g),e.component("Message",y),m(e,n),s(e,w),s(e,v),s(e,k)};D();
//# sourceMappingURL=player.6effb5f2.js.map
