import{x as s}from"./icons.ef86ff2e.js";import{d as r,a as c,b as d,c as i,e as _,z as l,S as u,q as f}from"./registerWidgets.68b4d727.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="85d99976-dc6f-4818-b4e9-9045425a99ea",e._sentryDebugIdIdentifier="sentry-dbid-85d99976-dc6f-4818-b4e9-9045425a99ea")}catch{}})();const p=r({__name:"BackButton",emits:["exitFullscreenPreview"],setup(e,{emit:t}){return(o,n)=>{const a=c("icon");return d(),i("button",{class:"back-btn",onClick:n[0]||(n[0]=b=>t("exitFullscreenPreview"))},[_(a,{class:"icon",path:l(s),width:"20",height:"20",fill:"#5A677A"},null,8,["path"]),u(" Editor ")])}}});const w=f(p,[["__scopeId","data-v-eaeb3a6e"]]);export{w as B};
//# sourceMappingURL=BackButton.e07bee68.js.map
