import{S as p}from"./Sidebar.285d059a.js";import{N as u}from"./Navbar.4d0c713d.js";import{I as d,E as v,J as _,K as g,c as b,F as f,G as h,H as j}from"./icons.ea1ef9e9.js";import{a as s}from"./asyncComputed.5c8fd07f.js";import{P as z}from"./project.73d49dff.js";import"./utils.7963b0ba.js";import{O as I}from"./organization.e07951ff.js";import{d as P,K as r,an as y,b as k,c as x,e as t,z as i,x as B,F as $,J as w,a as E,q as N}from"./registerWidgets.69eb7b40.js";import"./Tooltip.b3ee6275.js";import"./logo.084e5d7c.js";import"./passwordlessManager.3c745f80.js";import"./pubsub.a0411919.js";const S={class:"project"},C=P({__name:"Project",setup(F){const l=w().params.projectId,{result:e}=s(()=>z.get(l)),{result:a}=s(()=>e.value?I.get(e.value.organizationId):Promise.resolve(null)),n=r(()=>{var o;return a.value&&e.value?[{label:(o=a.value)==null?void 0:o.name,path:`/organizations/${a.value.id}`},{label:e.value.name,path:`/projects/${e.value.id}`}]:void 0});y(()=>{console.log(n.value)});const c=r(()=>e.value?[{name:"Project",items:[{name:"Builds",path:"builds",icon:d},{name:"API Keys",path:"api-keys",icon:v},{name:"Env Vars",path:"env-vars",icon:_},{name:"Logs",icon:g,unavailable:!0,path:"logs"},{name:"Settings",icon:b,unavailable:!0,path:"settings"}]},{name:"Organization",items:[{name:"Projects",icon:f,path:`/organizations/${e.value.organizationId}/projects`},{name:"Members",icon:h,path:`/organizations/${e.value.organizationId}/members`},{name:"Billing",icon:j,path:`/organizations/${e.value.organizationId}/billing`,unavailable:!0}]}]:[]);return(o,M)=>{const m=E("router-view");return k(),x($,null,[t(u,{class:"nav",breadcrumb:i(n)},null,8,["breadcrumb"]),B("div",S,[t(p,{class:"sidebar",sections:i(c)},null,8,["sections"]),t(m)])],64)}}});const U=N(C,[["__scopeId","data-v-d700e412"]]);export{U as default};
//# sourceMappingURL=Project.0fa7805a.js.map
