[data-v-eaeb3a6e]:root{--main-font-family: DM Sans, sans-serif}[data-v-eaeb3a6e]:root{--abstra-neutral-color: #bbb;--abstra-primary-color: #ffee56;--abstra-dark-text-color: #1b1b23;--abstra-normal-text-color: #414a58;--abstra-main-color-dark: #343b46;--abstra-main-color-light: #ffd84c;--abstra-secondary-color-dark: #4c5767;--abstra-secondary-color-light: #feab4c;--abstra-background-base: #f9fafb;--abstra-main-color-blue: #2479df}.back-btn[data-v-eaeb3a6e]{cursor:pointer;display:flex;justify-content:center;align-items:center;gap:6px;padding:7px 14px;font-family:DM Sans,sans-serif;font-style:normal;font-weight:500;font-size:16px;line-height:20px;color:#5a677a;border:none;background:transparent;background:rgba(255,255,255,.9);box-shadow:0 0 4px #0000001f;border-radius:4px;position:fixed;bottom:48px;right:24px}
