import{q as n,a as r,b as i,t as c,f as d,g as p,_,h as u,k as f,T as l,P as h,C as b,M as g,s as y,i as m,j as s,l as w,m as v,n as k}from"./registerWidgets.eddc32f4.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="80adc7f1-1312-48ce-aabe-af681faab184",e._sentryDebugIdIdentifier="sentry-dbid-80adc7f1-1312-48ce-aabe-af681faab184")}catch{}})();const I={};function x(e,t){const o=r("router-view");return i(),c(o,{style:{"min-height":"100vh","box-sizing":"border-box",width:"100%"}})}const A=n(I,[["render",x]]),a=d({history:p("/"),routes:[{path:"/:path(.*)*",name:"player",component:()=>_(()=>import("./Player.ae32e828.js"),["assets/Player.ae32e828.js","assets/index.611a11f3.js","assets/registerWidgets.eddc32f4.js","assets/registerWidgets.a7e6ab4f.css","assets/log.3b9a52f8.js","assets/broker.c247ccf4.js","assets/passwordlessManager.8b97cbcd.js","assets/icons.54ab2234.js","assets/ActionButton.vue_vue_type_script_setup_true_lang.93a730d7.js","assets/Passwordless.a3421c62.js","assets/CircularLoading.c96bd1c9.js","assets/lottie.6d443700.js","assets/CircularLoading.f81b57b4.css","assets/Passwordless.2b58e538.css","assets/executeJs.808febb8.js","assets/PlayerNavbar.051aa9d4.js","assets/PlayerNavbar.1542e7ca.css","assets/WidgetsFrame.b21a0c80.js","assets/colors.bcdf4144.js","assets/WidgetsFrame.701a818b.css","assets/Modal.bb1eb9c5.js","assets/Modal.5aaf8eba.css","assets/executeJs.b0d1ede9.css","assets/broker.f87ad36d.css","assets/DashPlayer.b5377295.js","assets/runnerData.cdcfd570.js","assets/DashPlayer.a2bc20b8.css","assets/asyncComputed.562c187e.js","assets/Player.32200e3c.css"])}],scrollBehavior(e){if(e.hash)return{el:e.hash}}}),D=()=>{window.__dashBrokerHost="ws://localhost:8001";const e=u({render:()=>f(A)});l.init(),e.use(a),e.use(h),e.mount("#app"),e.component("VSelect",b),e.component("Markdown",g),e.component("Message",y),m(e,a),s(e,w),s(e,v),s(e,k)};D();
//# sourceMappingURL=player.3e823365.js.map
